@@ -16,8 +16,10 @@
 
 package org.kie.workbench.common.dmn.client.editors.types.listview;
 
+import java.util.Arrays;
 import java.util.List;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
@@ -27,7 +29,8 @@ import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
 import elemental2.dom.HTMLElement;
-import org.kie.workbench.common.dmn.api.definition.v1_1.ConstraintType;
+import org.kie.workbench.common.dmn.api.definition.model.ConstraintType;
+import org.kie.workbench.common.dmn.client.editors.types.DataTypeChangedEvent;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataType;
 import org.kie.workbench.common.dmn.client.editors.types.common.DataTypeManager;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
@@ -39,6 +42,7 @@ import org.uberfire.client.mvp.UberElemental;
 import org.uberfire.mvp.Command;
 
 import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.BOOLEAN;
+import static org.kie.workbench.common.dmn.api.property.dmn.types.BuiltInType.CONTEXT;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.ABOVE;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.BELOW;
 import static org.kie.workbench.common.dmn.client.editors.types.persistence.CreationType.NESTED;
@@ -63,6 +67,8 @@ public class DataTypeListItem {
 
     private final DataTypeNameFormatValidator nameFormatValidator;
 
+    private final Event<DataTypeChangedEvent> dataTypeChangedEvent;
+
     private DataType dataType;
 
     private int level;
@@ -79,6 +85,8 @@ public class DataTypeListItem {
 
     private ConstraintType oldConstraintType;
 
+    private String[] canNotHaveConstraintTypes;
+
     @Inject
     public DataTypeListItem(final View view,
                             final DataTypeSelect dataTypeSelectComponent,
@@ -87,7 +95,8 @@ public class DataTypeListItem {
                             final DataTypeManager dataTypeManager,
                             final DataTypeConfirmation confirmation,
                             final DataTypeNameFormatValidator nameFormatValidator,
-                            final Event<DataTypeEditModeToggleEvent> editModeToggleEvent) {
+                            final Event<DataTypeEditModeToggleEvent> editModeToggleEvent,
+                            final Event<DataTypeChangedEvent> dataTypeChangedEvent) {
         this.view = view;
         this.dataTypeSelectComponent = dataTypeSelectComponent;
         this.dataTypeConstraintComponent = dataTypeConstraintComponent;
@@ -96,11 +105,18 @@ public class DataTypeListItem {
         this.confirmation = confirmation;
         this.nameFormatValidator = nameFormatValidator;
         this.editModeToggleEvent = editModeToggleEvent;
+        this.dataTypeChangedEvent = dataTypeChangedEvent;
+        this.dataTypeListComponent.setOnValueChanged(value -> refreshConstraintComponent());
     }
 
     @PostConstruct
     void setup() {
         view.init(this);
+        canNotHaveConstraintTypes = new String[]{
+                BOOLEAN.getName(),
+                dataTypeManager.structure(),
+                CONTEXT.getName()
+        };
     }
 
     public void init(final DataTypeList dataTypeList) {
@@ -118,8 +134,8 @@ public class DataTypeListItem {
         this.level = level;
 
         setupSelectComponent();
-        setupConstraintComponent();
         setupListComponent();
+        setupConstraintComponent();
         setupView();
     }
 
@@ -165,6 +181,10 @@ public class DataTypeListItem {
         return level;
     }
 
+    public String[] getCanNotHaveConstraintTypes() {
+        return canNotHaveConstraintTypes;
+    }
+
     void expandOrCollapseSubTypes() {
         if (view.isCollapsed()) {
             expand();
@@ -249,13 +269,23 @@ public class DataTypeListItem {
             final String newDataTypeHash = getNewDataTypeHash(dataType, referenceDataTypeHash);
             dataTypeList.fireOnDataTypeListItemUpdateCallback(newDataTypeHash);
             insertNewFieldIfDataTypeIsStructure(newDataTypeHash);
+            fireDataChangedEvent();
         };
     }
 
+    void fireDataChangedEvent() {
+        dataTypeChangedEvent.fire(new DataTypeChangedEvent());
+    }
+
     void insertNewFieldIfDataTypeIsStructure(final String hash) {
-        if (isStructureType() && getDataType().getSubDataTypes().isEmpty()) {
-            dataTypeList.insertNestedField(hash);
-        }
+
+        final Optional<DataTypeListItem> updatedItem = dataTypeList.findItemByDataTypeHash(hash);
+
+        updatedItem.ifPresent(item -> {
+            if (item.isStructureType() && !item.getDataType().hasSubDataTypes()) {
+                dataTypeList.insertNestedField(hash);
+            }
+        });
     }
 
     List<DataType> persist(final DataType dataType) {
@@ -326,6 +356,8 @@ public class DataTypeListItem {
             destroyedDataTypes.removeAll(removedDataTypes);
 
             dataTypeList.refreshItemsByUpdatedDataTypes(destroyedDataTypes);
+
+            fireDataChangedEvent();
         };
     }
 
@@ -471,21 +503,55 @@ public class DataTypeListItem {
     }
 
     void refreshConstraintComponent() {
-        if (isBooleanType() || isStructureType()) {
+        if (canNotHaveConstraint()) {
             dataTypeConstraintComponent.disable();
         } else {
             dataTypeConstraintComponent.enable();
         }
     }
 
-    private boolean isBooleanType() {
-        return Objects.equals(BOOLEAN.getName(), getType());
+    private boolean canNotHaveConstraint() {
+        if (isList()) {
+            return true;
+        }
+
+        if (Stream.of(getCanNotHaveConstraintTypes())
+                .filter(type -> Objects.equals(type, getType()))
+                .findFirst()
+                .isPresent()) {
+            return true;
+        }
+
+        if (isIndirectCanNotHaveConstraintType()) {
+            return true;
+        }
+
+        return false;
     }
 
-    private boolean isStructureType() {
+    boolean isStructureType() {
         return Objects.equals(dataTypeManager.structure(), getType());
     }
 
+    boolean isIndirectCanNotHaveConstraintType() {
+        final String currentValue = dataTypeSelectComponent.getValue();
+        return isIndirectTypeOf(currentValue, getCanNotHaveConstraintTypes());
+    }
+
+    private boolean isIndirectTypeOf(final String currentValue, final String... types) {
+        final List<DataType> customDataTypes = dataTypeSelectComponent.getCustomDataTypes();
+        final Optional<DataType> customType = customDataTypes.stream()
+                .filter(d -> d.getName().equals(currentValue))
+                .findFirst();
+
+        if (customType.isPresent()) {
+            final String type = customType.get().getType();
+            return Arrays.stream(types).anyMatch(t -> t.equals(type)) || isIndirectTypeOf(type, types);
+        }
+
+        return false;
+    }
+
     public interface View extends UberElemental<DataTypeListItem> {
 
         void setDataType(final DataType dataType);
