@@ -181,7 +181,7 @@ public abstract class BaseProjectImportService implements ImportService {
                           true);
 
         configuration.add(EnvironmentParameters.SPACE,
-                          SYSTEM);
+                          this.getDefaultSpace());
 
         RepositoryInfo repositoryConfig = new RepositoryInfo(alias,
                                                              false,
@@ -190,6 +190,10 @@ public abstract class BaseProjectImportService implements ImportService {
         return repositoryConfig;
     }
 
+    protected String getDefaultSpace() {
+        return SYSTEM;
+    }
+
     protected Map<String, Object> buildGitEnv(String url,
                                               String username,
                                               String password,
@@ -200,7 +204,7 @@ public abstract class BaseProjectImportService implements ImportService {
             put(SCHEME,
                 GitRepository.SCHEME.toString());
             put("replaceIfExists",
-                true);
+                false);
             put("username",
                 username);
             put("password",
