@@ -28,6 +28,7 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Collectors;
+
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -53,6 +54,7 @@ import org.guvnor.structure.repositories.NewBranchEvent;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.RepositoryUpdatedEvent;
+import org.guvnor.structure.repositories.changerequest.ChangeRequestService;
 import org.guvnor.structure.security.OrganizationalUnitAction;
 import org.guvnor.structure.security.RepositoryAction;
 import org.jboss.errai.bus.server.annotations.Service;
@@ -70,7 +72,6 @@ import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.OrganizationalUnitRepositoryInfo;
 import org.kie.workbench.common.screens.library.api.ProjectAssetsQuery;
-import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
 import org.kie.workbench.common.services.refactoring.backend.server.query.standard.FindAllLibraryAssetsQuery;
 import org.kie.workbench.common.services.refactoring.backend.server.query.standard.LibraryValueFileExtensionIndexTerm;
@@ -86,7 +87,6 @@ import org.slf4j.LoggerFactory;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.commons.cluster.ClusterService;
-import org.uberfire.ext.security.management.api.exception.NoImplementationAvailableException;
 import org.uberfire.ext.security.management.api.service.UserManagerService;
 import org.uberfire.ext.security.management.impl.SearchRequestImpl;
 import org.uberfire.io.IOService;
@@ -107,9 +107,6 @@ public class LibraryServiceImpl implements LibraryService {
     private RefactoringQueryService refactoringQueryService;
     private OrganizationalUnitService ouService;
     private LibraryPreferences preferences;
-
-    private LibraryInternalPreferences internalPreferences;
-
     private AuthorizationManager authorizationManager;
     private SessionInfo sessionInfo;
     private ExplorerServiceHelper explorerServiceHelper;
@@ -126,6 +123,7 @@ public class LibraryServiceImpl implements LibraryService {
     private Event<RepositoryUpdatedEvent> repositoryUpdatedEvent;
     private SpaceConfigStorageRegistry spaceConfigStorageRegistry;
     private ClusterService clusterService;
+    private ChangeRequestService changeRequestService;
 
     public LibraryServiceImpl() {
     }
@@ -141,7 +139,6 @@ public class LibraryServiceImpl implements LibraryService {
                               final KieModuleService moduleService,
                               final ExamplesService examplesService,
                               @Named("ioStrategy") final IOService ioService,
-                              final LibraryInternalPreferences internalPreferences,
                               final UserManagerService userManagerService,
                               final IndexStatusOracle indexOracle,
                               final RepositoryService repoService,
@@ -150,7 +147,8 @@ public class LibraryServiceImpl implements LibraryService {
                               final ConfiguredRepositories configuredRepositories,
                               final Event<RepositoryUpdatedEvent> repositoryUpdatedEvent,
                               final SpaceConfigStorageRegistry spaceConfigStorageRegistry,
-                              final ClusterService clusterService) {
+                              final ClusterService clusterService,
+                              final ChangeRequestService changeRequestService) {
         this.ouService = ouService;
         this.refactoringQueryService = refactoringQueryService;
         this.preferences = preferences;
@@ -161,7 +159,6 @@ public class LibraryServiceImpl implements LibraryService {
         this.moduleService = moduleService;
         this.examplesService = examplesService;
         this.ioService = ioService;
-        this.internalPreferences = internalPreferences;
         this.userManagerService = userManagerService;
         this.indexOracle = indexOracle;
         this.repoService = repoService;
@@ -171,6 +168,7 @@ public class LibraryServiceImpl implements LibraryService {
         this.repositoryUpdatedEvent = repositoryUpdatedEvent;
         this.spaceConfigStorageRegistry = spaceConfigStorageRegistry;
         this.clusterService = clusterService;
+        this.changeRequestService = changeRequestService;
     }
 
     @Override
@@ -196,16 +194,10 @@ public class LibraryServiceImpl implements LibraryService {
 
     @Override
     public LibraryInfo getLibraryInfo(final OrganizationalUnit organizationalUnit) {
-        final Collection<WorkspaceProject> projects = projectService.getAllWorkspaceProjects(organizationalUnit).stream()
+        final List<WorkspaceProject> projects = projectService.getAllWorkspaceProjects(organizationalUnit).stream()
                 .filter(p -> userCanReadProject(p))
                 .collect(Collectors.toList());
 
-        projects.stream().forEach(p -> {
-            if (p.getMainModule() != null) {
-                p.getMainModule().setNumberOfAssets(getNumberOfAssets(p));
-            }
-        });
-
         return new LibraryInfo(projects);
     }
 
@@ -404,14 +396,15 @@ public class LibraryServiceImpl implements LibraryService {
     }
 
     @Override
-    public List<String> getAllUsers() {
+    public synchronized List<String> getAllUsers() {
         try {
             final List<User> users = userManagerService.search(new SearchRequestImpl("",
                                                                                      1,
                                                                                      Integer.MAX_VALUE)).getResults();
             return users.stream().map(User::getIdentifier).collect(Collectors.toList());
-        } catch (NoImplementationAvailableException e) {
-            return Collections.singletonList("admin");
+        } catch (Exception e) {
+            log.error("Error while searching all users: " + e.getClass().getCanonicalName() );
+            return Collections.emptyList();
         }
     }
 
@@ -459,13 +452,24 @@ public class LibraryServiceImpl implements LibraryService {
     @Override
     public void removeBranch(final WorkspaceProject project,
                              final Branch branch) {
-        final org.uberfire.java.nio.file.Path branchPath = pathUtil.convert(branch.getPath());
-        ioService.delete(branchPath);
-        deleteBranchPermissions(project.getSpace().getName(),
-                                project.getRepository().getIdentifier(),
-                                branch.getName());
-        this.repositoryUpdatedEvent.fire(new RepositoryUpdatedEvent(repoService.getRepositoryFromSpace(project.getSpace(),
-                                                                                                       project.getRepository().getAlias())));
+        try {
+            ioService.startBatch(pathUtil.convert(branch.getPath()).getFileSystem());
+
+            repoService.getRepositoryFromSpace(project.getSpace(), project.getRepository().getAlias()).getBranch(branch.getName()).ifPresent(updatedBranch -> {
+                final org.uberfire.java.nio.file.Path branchPath = pathUtil.convert(branch.getPath());
+                ioService.delete(branchPath);
+                deleteBranchPermissions(project.getSpace().getName(),
+                                        project.getRepository().getIdentifier(),
+                                        branch.getName());
+                deleteAssociatedChangeRequests(project.getSpace().getName(),
+                                               project.getRepository().getAlias(),
+                                               branch.getName());
+                this.repositoryUpdatedEvent.fire(new RepositoryUpdatedEvent(repoService.getRepositoryFromSpace(project.getSpace(),
+                                                                                                               project.getRepository().getAlias())));
+            });
+        } finally {
+            ioService.endBatch();
+        }
     }
 
     @Override
@@ -498,6 +502,14 @@ public class LibraryServiceImpl implements LibraryService {
                                                                           projectIdentifier);
     }
 
+    private void deleteAssociatedChangeRequests(final String spaceName,
+                                                final String repositoryAlias,
+                                                final String associatedBranchName) {
+        changeRequestService.deleteChangeRequests(spaceName,
+                                                  repositoryAlias,
+                                                  associatedBranchName);
+    }
+
     private void fireNewBranchEvent(final Path targetRoot,
                                     final org.uberfire.java.nio.file.Path nioTargetRepositoryRoot,
                                     final org.uberfire.java.nio.file.Path nioSourceRepositoryRoot) {
@@ -526,11 +538,6 @@ public class LibraryServiceImpl implements LibraryService {
         return preferences;
     }
 
-    LibraryInternalPreferences getInternalPreferences() {
-        internalPreferences.load();
-        return internalPreferences;
-    }
-
     POM createPOM(final String projectName,
                   final String projectDescription,
                   final GAV gav) {
@@ -571,10 +578,7 @@ public class LibraryServiceImpl implements LibraryService {
 
     @Override
     public OrganizationalUnit getDefaultOrganizationalUnit() {
-        String defaultOUIdentifier = getInternalPreferences().getLastOpenedOrganizationalUnit();
-        if (defaultOUIdentifier == null || defaultOUIdentifier.isEmpty()) {
-            defaultOUIdentifier = getPreferences().getOrganizationalUnitPreferences().getName();
-        }
+        final String defaultOUIdentifier = getPreferences().getOrganizationalUnitPreferences().getName();
 
         final List<OrganizationalUnit> organizationalUnits = getOrganizationalUnits();
         final Optional<OrganizationalUnit> defaultOU = getOrganizationalUnit(defaultOUIdentifier,
