@@ -46,6 +46,7 @@ import org.guvnor.structure.repositories.NewBranchEvent;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.RepositoryUpdatedEvent;
+import org.guvnor.structure.repositories.changerequest.ChangeRequestService;
 import org.guvnor.structure.security.RepositoryAction;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
@@ -61,7 +62,6 @@ import org.kie.workbench.common.screens.library.api.AssetQueryResult.ResultType;
 import org.kie.workbench.common.screens.library.api.LibraryInfo;
 import org.kie.workbench.common.screens.library.api.OrganizationalUnitRepositoryInfo;
 import org.kie.workbench.common.screens.library.api.ProjectAssetsQuery;
-import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryOrganizationalUnitPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryPreferences;
 import org.kie.workbench.common.screens.library.api.preferences.LibraryProjectPreferences;
@@ -118,9 +118,6 @@ public class LibraryServiceImplTest {
     @Mock
     private LibraryPreferences preferences;
 
-    @Mock
-    private LibraryInternalPreferences internalPreferences;
-
     @Mock
     private ExplorerServiceHelper explorerServiceHelper;
 
@@ -159,6 +156,9 @@ public class LibraryServiceImplTest {
     @Mock
     private ClusterService clusterService;
 
+    @Mock
+    private ChangeRequestService changeRequestService;
+
     @Mock
     private Event<NewBranchEvent> newBranchEvent;
 
@@ -227,7 +227,6 @@ public class LibraryServiceImplTest {
                                                     moduleService,
                                                     examplesService,
                                                     ioService,
-                                                    internalPreferences,
                                                     userManagerService,
                                                     indexOracle,
                                                     repositoryService,
@@ -236,7 +235,8 @@ public class LibraryServiceImplTest {
                                                     configuredRepositories,
                                                     repositoryUpdatedEvent,
                                                     spaceConfigStorageRegistry,
-                                                    clusterService
+                                                    clusterService,
+                                                    changeRequestService
         ));
     }
 
@@ -781,23 +781,26 @@ public class LibraryServiceImplTest {
 
     @Test
     public void removeBranchTest() {
-        final Branch masterBranch = makeBranch("master", "repo1");
+        final Branch otherBranch = makeBranch("repo1-branch1", "repo1");
         final org.uberfire.java.nio.file.Path baseBranchPath = mock(org.uberfire.java.nio.file.Path.class);
         final FileSystem fileSystem = mock(FileSystem.class);
         final FileSystemProvider fileSystemProvider = mock(FileSystemProvider.class);
         doReturn(fileSystemProvider).when(fileSystem).provider();
         doReturn(fileSystem).when(baseBranchPath).getFileSystem();
-        doReturn(baseBranchPath).when(pathUtil).convert(masterBranch.getPath());
+        doReturn(baseBranchPath).when(pathUtil).convert(otherBranch.getPath());
 
         final WorkspaceProject project = mock(WorkspaceProject.class);
         doReturn(repo1).when(project).getRepository();
-        doReturn(new Space("my-space")).when(project).getSpace();
-
+        final Space space = new Space("my-space");
+        doReturn(space).when(project).getSpace();
         doReturn(mock(SpaceConfigStorage.class)).when(spaceConfigStorageRegistry).get("my-space");
+        doReturn(repo1).when(repositoryService).getRepositoryFromSpace(space, "repo_created_by_user");
 
-        libraryService.removeBranch(project, masterBranch);
+        libraryService.removeBranch(project, otherBranch);
 
+        verify(ioService).startBatch(fileSystem);
         verify(ioService).delete(baseBranchPath);
+        verify(ioService).endBatch();
     }
 
     @Test
