@@ -16,6 +16,9 @@
 
 package org.kie.workbench.common.screens.library.client.screens.project;
 
+import java.util.Arrays;
+import java.util.List;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
@@ -26,27 +29,28 @@ import elemental2.dom.HTMLElement;
 import elemental2.promise.Promise;
 import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
+import org.guvnor.common.services.project.events.RepositoryContributorsUpdatedEvent;
 import org.guvnor.common.services.project.model.WorkspaceProject;
-import org.guvnor.messageconsole.client.console.widget.button.ViewHideAlertsButtonPresenter;
-import org.guvnor.structure.client.security.OrganizationalUnitController;
-import org.guvnor.structure.events.AfterEditOrganizationalUnitEvent;
-import org.jboss.errai.bus.client.api.messaging.Message;
+import org.guvnor.structure.repositories.changerequest.portable.ChangeRequestListUpdatedEvent;
+import org.guvnor.structure.repositories.changerequest.portable.ChangeRequestStatus;
+import org.guvnor.structure.repositories.changerequest.portable.ChangeRequestStatusUpdatedEvent;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.dom.elemental2.Elemental2DomUtil;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
-import org.jboss.errai.ui.client.local.api.elemental2.IsElement;
 import org.kie.workbench.common.screens.defaulteditor.client.editor.NewFileUploader;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
 import org.kie.workbench.common.screens.library.client.screens.assets.AssetsScreen;
 import org.kie.workbench.common.screens.library.client.screens.assets.events.UpdatedAssetsEvent;
-import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.edit.EditContributorsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ContributorsListPresenter;
+import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ProjectContributorsListServiceImpl;
+import org.kie.workbench.common.screens.library.client.screens.project.actions.ProjectMainActions;
+import org.kie.workbench.common.screens.library.client.screens.project.branch.delete.DeleteBranchPopUpScreen;
+import org.kie.workbench.common.screens.library.client.screens.project.changerequest.list.ChangeRequestListPresenter;
 import org.kie.workbench.common.screens.library.client.screens.project.delete.DeleteProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.screens.project.rename.RenameProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.settings.SettingsPresenter;
 import org.kie.workbench.common.screens.library.client.util.LibraryPlaces;
-import org.kie.workbench.common.screens.projecteditor.client.build.BuildExecutor;
 import org.kie.workbench.common.screens.projecteditor.client.validation.ProjectNameValidator;
 import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
 import org.kie.workbench.common.widgets.client.handlers.NewResourcePresenter;
@@ -59,7 +63,6 @@ import org.uberfire.client.mvp.UberElemental;
 import org.uberfire.client.promise.Promises;
 import org.uberfire.ext.editor.commons.client.file.CommandWithFileNameAndCommitMessage;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
-import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.workbench.events.NotificationEvent;
 
@@ -70,13 +73,12 @@ public class ProjectScreen {
     private Elemental2DomUtil elemental2DomUtil;
     protected WorkspaceProject workspaceProject;
 
-    public interface View extends UberElemental<ProjectScreen>,
-                                  BuildExecutor.View {
-
-        void addMainAction(IsElement action);
+    public interface View extends UberElemental<ProjectScreen> {
 
         void setAssetsCount(int count);
 
+        void setChangeRequestsCount(int count);
+
         void setContributorsCount(int count);
 
         void setContent(HTMLElement content);
@@ -87,17 +89,15 @@ public class ProjectScreen {
 
         void setImportAssetVisible(boolean visible);
 
-        void setEditContributorsVisible(boolean visible);
-
         void setDuplicateVisible(boolean visible);
 
         void setReimportVisible(boolean visible);
 
         void setDeleteProjectVisible(boolean visible);
 
-        void setBuildEnabled(boolean enabled);
+        void setDeleteBranchVisible(boolean visible);
 
-        void setDeployEnabled(boolean enabled);
+        void setSubmitChangeRequestVisible(boolean visible);
 
         void setActionsVisible(boolean visible);
 
@@ -106,21 +106,26 @@ public class ProjectScreen {
         String getItemSuccessfullyDuplicatedMessage();
 
         String getReimportSuccessfulMessage();
+
+        void showBusyIndicator(String loadingMessage);
+
+        void hideBusyIndicator();
+
+        void addMainAction(HTMLElement element);
     }
 
     private final LibraryPlaces libraryPlaces;
 
     private AssetsScreen assetsScreen;
+    private ChangeRequestListPresenter changeRequestsScreen;
     private ContributorsListPresenter contributorsListScreen;
     private ProjectMetricsScreen projectMetricsScreen;
     private ProjectController projectController;
     private SettingsPresenter settingsPresenter;
-    private OrganizationalUnitController organizationalUnitController;
     private final NewFileUploader newFileUploader;
     private final NewResourcePresenter newResourcePresenter;
-    private BuildExecutor buildExecutor;
-    private ManagedInstance<EditContributorsPopUpPresenter> editContributorsPopUpPresenter;
     private ManagedInstance<DeleteProjectPopUpScreen> deleteProjectPopUpScreen;
+    private ManagedInstance<DeleteBranchPopUpScreen> deleteBranchPopUpScreen;
     private ManagedInstance<RenameProjectPopUpScreen> renameProjectPopUpScreen;
     private Caller<LibraryService> libraryService;
     private ProjectScreen.View view;
@@ -129,22 +134,22 @@ public class ProjectScreen {
     private ProjectNameValidator projectNameValidator;
     private Promises promises;
     private Event<NotificationEvent> notificationEvent;
-    private ViewHideAlertsButtonPresenter viewHideAlertsButtonPresenter;
+    private ProjectContributorsListServiceImpl projectContributorsListService;
+    private ProjectMainActions projectMainActions;
 
     @Inject
     public ProjectScreen(final View view,
                          final LibraryPlaces libraryPlaces,
                          final AssetsScreen assetsScreen,
+                         final ChangeRequestListPresenter changeRequestsScreen,
                          final ContributorsListPresenter contributorsListScreen,
                          final ProjectMetricsScreen projectMetricsScreen,
                          final ProjectController projectController,
                          final SettingsPresenter settingsPresenter,
-                         final OrganizationalUnitController organizationalUnitController,
                          final NewFileUploader newFileUploader,
                          final NewResourcePresenter newResourcePresenter,
-                         final BuildExecutor buildExecutor,
-                         final ManagedInstance<EditContributorsPopUpPresenter> editContributorsPopUpPresenter,
                          final ManagedInstance<DeleteProjectPopUpScreen> deleteProjectPopUpScreen,
+                         final ManagedInstance<DeleteBranchPopUpScreen> deleteBranchPopUpScreen,
                          final ManagedInstance<RenameProjectPopUpScreen> renameProjectPopUpScreen,
                          final Caller<LibraryService> libraryService,
                          final Caller<ProjectScreenService> projectScreenService,
@@ -152,20 +157,20 @@ public class ProjectScreen {
                          final ProjectNameValidator projectNameValidator,
                          final Promises promises,
                          final Event<NotificationEvent> notificationEvent,
-                         final ViewHideAlertsButtonPresenter viewHideAlertsButtonPresenter) {
+                         final ProjectContributorsListServiceImpl projectContributorsListService,
+                         final ProjectMainActions projectMainActions) {
         this.view = view;
         this.libraryPlaces = libraryPlaces;
         this.assetsScreen = assetsScreen;
+        this.changeRequestsScreen = changeRequestsScreen;
         this.contributorsListScreen = contributorsListScreen;
         this.projectMetricsScreen = projectMetricsScreen;
         this.projectController = projectController;
         this.settingsPresenter = settingsPresenter;
-        this.organizationalUnitController = organizationalUnitController;
         this.newFileUploader = newFileUploader;
         this.newResourcePresenter = newResourcePresenter;
-        this.buildExecutor = buildExecutor;
-        this.editContributorsPopUpPresenter = editContributorsPopUpPresenter;
         this.deleteProjectPopUpScreen = deleteProjectPopUpScreen;
+        this.deleteBranchPopUpScreen = deleteBranchPopUpScreen;
         this.renameProjectPopUpScreen = renameProjectPopUpScreen;
         this.libraryService = libraryService;
         this.projectScreenService = projectScreenService;
@@ -173,49 +178,86 @@ public class ProjectScreen {
         this.projectNameValidator = projectNameValidator;
         this.promises = promises;
         this.notificationEvent = notificationEvent;
-        this.viewHideAlertsButtonPresenter = viewHideAlertsButtonPresenter;
+        this.projectContributorsListService = projectContributorsListService;
         this.elemental2DomUtil = new Elemental2DomUtil();
+        this.projectMainActions = projectMainActions;
     }
 
     @PostConstruct
     public void initialize() {
         this.workspaceProject = this.libraryPlaces.getActiveWorkspace();
         this.view.init(this);
-        this.buildExecutor.init(this.view);
         this.view.setTitle(libraryPlaces.getActiveWorkspace().getName());
-        this.view.addMainAction(viewHideAlertsButtonPresenter.getView());
-        this.resolveContributorsCount();
+        this.view.addMainAction(projectMainActions.getElement());
         this.resolveAssetsCount();
         this.showAssets();
 
-        final boolean userCanUpdateProject = this.userCanUpdateProject();
-        final boolean userCanEditContributors = this.canEditContributors();
-        final boolean userCanDeleteProject = this.userCanDeleteProject();
-        final boolean userCanBuildProject = this.userCanBuildProject();
-        final boolean userCanCreateProjects = this.userCanCreateProjects();
+        projectController.canUpdateProject(workspaceProject).then(userCanUpdateProject -> {
+            this.view.setAddAssetVisible(userCanUpdateProject);
+            this.view.setSubmitChangeRequestVisible(userCanUpdateProject);
+            this.view.setImportAssetVisible(userCanUpdateProject);
+            this.view.setReimportVisible(userCanUpdateProject);
 
-        this.view.setAddAssetVisible(userCanUpdateProject);
-        this.view.setImportAssetVisible(userCanUpdateProject);
-        this.view.setEditContributorsVisible(userCanEditContributors);
-        this.view.setDuplicateVisible(userCanCreateProjects);
-        this.view.setReimportVisible(userCanUpdateProject);
-        this.view.setDeleteProjectVisible(userCanDeleteProject);
-        this.view.setBuildEnabled(userCanBuildProject);
-        this.view.setDeployEnabled(userCanBuildProject);
+            newFileUploader.acceptContext(new Callback<Boolean, Void>() {
+                @Override
+                public void onFailure(Void reason) {
+                    view.setImportAssetVisible(false);
+                }
 
-        this.view.setActionsVisible(userCanUpdateProject || userCanEditContributors || userCanDeleteProject || userCanBuildProject || userCanCreateProjects);
+                @Override
+                public void onSuccess(Boolean result) {
+                    view.setImportAssetVisible(result && userCanUpdateProject);
+                }
+            });
 
-        newFileUploader.acceptContext(new Callback<Boolean, Void>() {
-            @Override
-            public void onFailure(Void reason) {
-                view.setImportAssetVisible(false);
-            }
-
-            @Override
-            public void onSuccess(Boolean result) {
-                view.setImportAssetVisible(result && userCanUpdateProject);
-            }
+            return promises.resolve();
         });
+
+        final boolean userCanCreateProjects = this.userCanCreateProjects();
+        this.view.setDuplicateVisible(userCanCreateProjects);
+
+        final boolean userCanDeleteProject = this.userCanDeleteProject();
+        this.view.setDeleteProjectVisible(userCanDeleteProject);
+
+        projectController.canDeleteBranch(workspaceProject).then(userCanDeleteBranch -> {
+            this.view.setDeleteBranchVisible(userCanDeleteBranch);
+            return promises.resolve();
+        });
+
+        projectController.canSubmitChangeRequest(workspaceProject).then(userCanSubmitChangeRequest -> {
+            this.view.setSubmitChangeRequestVisible(userCanSubmitChangeRequest);
+            return promises.resolve();
+        });
+
+        setupMainActions();
+
+        final List<Promise<Boolean>> permissionPromises = Arrays.asList(projectController.canUpdateProject(workspaceProject),
+                                                                        projectController.canDeleteBranch(workspaceProject),
+                                                                        promises.resolve(userCanDeleteProject()),
+                                                                        promises.resolve(userCanCreateProjects()));
+        promises.reduce(promises.resolve(false), permissionPromises, (p1, p2) -> p1.then(resultP1 -> p2.then(resultP2 -> this.promises.resolve(resultP1 || resultP2)))).then(thereAreActionsToDisplay -> {
+            this.view.setActionsVisible(thereAreActionsToDisplay);
+            return promises.resolve();
+        });
+
+        this.setupChangeRequestList();
+
+        contributorsListScreen.setup(projectContributorsListService,
+                                     contributorCount -> this.view.setContributorsCount(contributorCount));
+    }
+
+    private void setupMainActions() {
+        projectController.canBuildProject(workspaceProject).then(userCanBuildProject -> {
+            projectMainActions.setBuildEnabled(userCanBuildProject);
+            return promises.resolve();
+        });
+
+        projectController.canDeployProject(workspaceProject).then(userCanDeployProject -> {
+            projectMainActions.setDeployEnabled(userCanDeployProject);
+            return promises.resolve();
+        });
+
+        projectMainActions.setRedeployEnabled(workspaceProject.getMainModule().getPom().getGav().isSnapshot());
     }
 
     @OnMayClose
@@ -227,29 +269,50 @@ public class ProjectScreen {
         this.view.setAssetsCount(assetsCount);
     }
 
+    public void setChangeRequestsCount(final Integer openChangeRequestsCount) {
+        this.view.setChangeRequestsCount(openChangeRequestsCount);
+    }
+
     public void onAddAsset(@Observes NewResourceSuccessEvent event) {
         resolveAssetsCount();
     }
 
+    public void onChangeRequestListUpdated(@Observes final ChangeRequestListUpdatedEvent event) {
+        if (event.getRepositoryId().equals(workspaceProject.getRepository().getIdentifier())) {
+            this.setupChangeRequestList();
+        }
+    }
+
+    public void onChangeRequestStatusUpdated(@Observes final ChangeRequestStatusUpdatedEvent event) {
+        if (event.getRepositoryId().equals(workspaceProject.getRepository().getIdentifier()) &&
+                (event.getOldStatus() == ChangeRequestStatus.OPEN ||
+                        event.getNewStatus() == ChangeRequestStatus.OPEN)) {
+            this.setupChangeRequestList();
+        }
+    }
+
+    private void setupChangeRequestList() {
+        this.changeRequestsScreen.setupList(this::setChangeRequestsCount);
+    }
+
     public void onAssetsUpdated(@Observes UpdatedAssetsEvent event) {
         resolveAssetsCount();
     }
 
-    public void onContributorsUpdated(@Observes AfterEditOrganizationalUnitEvent event) {
-        resolveContributorsCount();
+    public void onRepositoryContributorsUpdated(@Observes final RepositoryContributorsUpdatedEvent repositoryUpdatedEvent) {
+        if (repositoryUpdatedEvent.getRepository().getIdentifier().equals(libraryPlaces.getActiveWorkspace().getRepository().getIdentifier())) {
+            view.setContributorsCount(repositoryUpdatedEvent.getRepository().getContributors().size());
+        }
     }
 
     public void changeProjectAndTitleWhenContextChange(@Observes final WorkspaceProjectContextChangeEvent current) {
         if (current.getWorkspaceProject() != null) {
             this.workspaceProject = current.getWorkspaceProject();
             this.view.setTitle(workspaceProject.getName());
+            setupMainActions();
         }
     }
 
-    private void resolveContributorsCount() {
-        this.view.setContributorsCount(this.contributorsListScreen.getContributorsCount());
-    }
-
     private void resolveAssetsCount() {
         this.libraryService.call((Integer numberOfAssets) -> this.setAssetsCount(numberOfAssets))
                 .getNumberOfAssets(this.workspaceProject);
@@ -259,6 +322,10 @@ public class ProjectScreen {
         this.view.setContent(this.assetsScreen.getView().getElement());
     }
 
+    public void showChangeRequests() {
+        this.view.setContent(this.changeRequestsScreen.getView().getElement());
+    }
+
     public void showMetrics() {
         this.projectMetricsScreen.onStartup(workspaceProject);
         this.view.setContent(elemental2DomUtil.asHTMLElement(this.projectMetricsScreen.getView().getElement()));
@@ -273,23 +340,52 @@ public class ProjectScreen {
         return this.libraryPlaces.getActiveWorkspace().getName();
     }
 
-    public void delete() {
+    public void deleteProject() {
         if (userCanDeleteProject()) {
             final DeleteProjectPopUpScreen popUp = deleteProjectPopUpScreen.get();
             popUp.show(this.workspaceProject);
         }
     }
 
+    public void deleteBranch() {
+        projectController.canDeleteBranch(workspaceProject).then(userCanDeleteBranch -> {
+            if (userCanDeleteBranch) {
+                final DeleteBranchPopUpScreen popUp = deleteBranchPopUpScreen.get();
+                popUp.show(this.libraryPlaces.getActiveWorkspace().getBranch());
+            }
+
+            return promises.resolve();
+        });
+    }
+
+    public void submitChangeRequest() {
+        projectController.canSubmitChangeRequest(workspaceProject).then(userCanSubmitChangeRequest -> {
+            if (Boolean.TRUE.equals(userCanSubmitChangeRequest)) {
+                this.libraryPlaces.goToSubmitChangeRequestScreen();
+            }
+
+            return promises.resolve();
+        });
+    }
+
     public void addAsset() {
-        if (userCanUpdateProject()) {
-            this.libraryPlaces.goToAddAsset();
-        }
+        projectController.canUpdateProject(workspaceProject).then(userCanUpdateProject -> {
+            if (userCanUpdateProject) {
+                this.libraryPlaces.goToAddAsset();
+            }
+
+            return promises.resolve();
+        });
     }
 
     public void importAsset() {
-        if (userCanUpdateProject()) {
-            newFileUploader.getCommand(newResourcePresenter).execute();
-        }
+        projectController.canUpdateProject(workspaceProject).then(userCanUpdateProject -> {
+            if (userCanUpdateProject) {
+                newFileUploader.getCommand(newResourcePresenter).execute();
+            }
+
+            return promises.resolve();
+        });
     }
 
     public void showSettings() {
@@ -301,17 +397,14 @@ public class ProjectScreen {
     }
 
     public void rename() {
-        if (userCanUpdateProject()) {
-            final RenameProjectPopUpScreen popUp = renameProjectPopUpScreen.get();
-            popUp.show(this.workspaceProject);
-        }
-    }
+        projectController.canUpdateProject(workspaceProject).then(userCanUpdateProject -> {
+            if (userCanUpdateProject) {
+                final RenameProjectPopUpScreen popUp = renameProjectPopUpScreen.get();
+                popUp.show(this.workspaceProject);
+            }
 
-    public void editContributors() {
-        if (this.canEditContributors()) {
-            final EditContributorsPopUpPresenter popUp = editContributorsPopUpPresenter.get();
-            popUp.show(this.workspaceProject.getOrganizationalUnit());
-        }
+            return promises.resolve();
+        });
     }
 
     public void duplicate() {
@@ -341,19 +434,23 @@ public class ProjectScreen {
     }
 
     public void reimport() {
-        if (this.userCanUpdateProject()) {
-            final Path pomXMLPath = workspaceProject.getMainModule().getPomXMLPath();
-            view.showBusyIndicator(view.getLoadingMessage());
+        projectController.canUpdateProject(workspaceProject).then(userCanUpdateProject -> {
+            if (userCanUpdateProject) {
+                final Path pomXMLPath = workspaceProject.getMainModule().getPomXMLPath();
+                view.showBusyIndicator(view.getLoadingMessage());
 
-            promises.promisify(projectScreenService, s -> {
-                s.reImport(pomXMLPath);
-            }).then(i -> {
-                view.hideBusyIndicator();
-                notificationEvent.fire(new NotificationEvent(view.getReimportSuccessfulMessage(),
-                                                             NotificationEvent.NotificationType.SUCCESS));
-                return promises.resolve();
-            }).catch_(this::onError);
-        }
+                promises.promisify(projectScreenService, s -> {
+                    s.reImport(pomXMLPath);
+                }).then(i -> {
+                    view.hideBusyIndicator();
+                    notificationEvent.fire(new NotificationEvent(view.getReimportSuccessfulMessage(),
+                                                                 NotificationEvent.NotificationType.SUCCESS));
+                    return promises.resolve();
+                }).catch_(this::onError);
+            }
+
+            return promises.resolve();
+        });
     }
 
     private Promise<Object> onError(final Object o) {
@@ -366,36 +463,12 @@ public class ProjectScreen {
         });
     }
 
-    public void build() {
-        if (this.userCanBuildProject()) {
-            this.buildExecutor.triggerBuild();
-        }
-    }
-
-    public void deploy() {
-        if (this.userCanBuildProject()) {
-            this.buildExecutor.triggerBuildAndDeploy();
-        }
-    }
-
-    public boolean canEditContributors() {
-        return this.organizationalUnitController.canUpdateOrgUnit(this.workspaceProject.getOrganizationalUnit());
-    }
-
     public boolean userCanDeleteProject() {
         return projectController.canDeleteProject(this.workspaceProject);
     }
 
-    public boolean userCanBuildProject() {
-        return workspaceProject.getMainModule() != null && projectController.canBuildProject(this.workspaceProject);
-    }
-
-    public boolean userCanUpdateProject() {
-        return workspaceProject.getMainModule() != null && projectController.canUpdateProject(this.workspaceProject);
-    }
-
     public boolean userCanCreateProjects() {
-        return projectController.canCreateProjects();
+        return projectController.canCreateProjects(libraryPlaces.getActiveSpace());
     }
 
     @WorkbenchPartView
