@@ -21,7 +21,9 @@ import java.util.List;
 import java.util.Optional;
 
 import org.guvnor.common.services.project.client.security.ProjectController;
+import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.Module;
+import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.repositories.Branch;
@@ -31,7 +33,6 @@ import org.kie.workbench.common.screens.explorer.client.utils.Classifier;
 import org.kie.workbench.common.screens.explorer.model.FolderItem;
 import org.kie.workbench.common.screens.explorer.model.FolderItemType;
 import org.kie.workbench.common.screens.library.api.AssetInfo;
-import org.kie.workbench.common.screens.library.api.AssetQueryResult;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectAssetsQuery;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
@@ -40,15 +41,18 @@ import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
 import org.uberfire.backend.vfs.Path;
-import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.spaces.Space;
 
-import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.*;
 
 public class ProjectScreenTestBase {
 
+    protected static final String GROUP_ID = "groupId";
+    protected static final String ARTIFACT = "artifact";
+    protected static final String VERSION = "0.1";
+
     @Mock
     protected LibraryPlaces libraryPlaces;
 
@@ -73,34 +77,30 @@ public class ProjectScreenTestBase {
     @Captor
     protected ArgumentCaptor<ProjectAssetsQuery> queryArgumentCaptor;
 
-    protected WorkspaceProject project;
-
     protected List<AssetInfo> assets = new ArrayList<>();
 
-    protected void mockClientResourceType() {
-        final ClientResourceType clientResourceType = mock(ClientResourceType.class);
-        doReturn(".txt").when(clientResourceType).getSuffix();
-        doReturn("Text file").when(clientResourceType).getDescription();
-        doReturn(clientResourceType).when(assetClassifier).findResourceType(any(FolderItem.class));
-    }
-
     protected WorkspaceProject createProject() {
         final Path rootPath = mock(Path.class);
         doReturn("git://modulePath").when(rootPath).toURI();
         final Module module = mock(Module.class);
+
         doReturn("mainModuleName").when(module).getModuleName();
         doReturn("modulePath").when(module).getIdentifier();
         doReturn(rootPath).when(module).getRootPath();
+        when(module.getPom()).thenReturn(new POM(new GAV(GROUP_ID, ARTIFACT, VERSION)));
+
         final Path pomPath = mock(Path.class);
         doReturn(pomPath).when(module).getPomXMLPath();
 
         final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
         final Repository repository = mock(Repository.class);
         final Path repositoryRootPath = mock(Path.class);
+        final Space space = mock(Space.class);
 
         doReturn(Optional.of(new Branch("master",
                                         repositoryRootPath))).when(repository).getDefaultBranch();
         doReturn("rootpath").when(repositoryRootPath).toURI();
+        doReturn(space).when(repository).getSpace();
 
         return new WorkspaceProject(organizationalUnit,
                                     repository,
@@ -123,19 +123,4 @@ public class ProjectScreenTestBase {
                              new Date(),
                              new Date());
     }
-
-    protected void mockAssets() {
-
-        assets.add(getAssetInfo("git://modulePath/folder1",
-                                FolderItemType.FOLDER,
-                                "folder1"));
-        assets.add(getAssetInfo("git://modulePath/file2.txt",
-                                FolderItemType.FILE,
-                                "file2.txt"));
-        assets.add(getAssetInfo("git://modulePath/file3.txt",
-                                FolderItemType.FILE,
-                                "file3.txt"));
-
-        when(libraryService.getProjectAssets(any(ProjectAssetsQuery.class))).thenReturn(AssetQueryResult.normal(assets));
-    }
 }
