@@ -41,6 +41,7 @@ import org.kie.workbench.common.screens.library.client.screens.organizationaluni
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ProjectContributorsListServiceImpl;
 import org.kie.workbench.common.screens.library.client.screens.project.actions.ProjectMainActions;
 import org.kie.workbench.common.screens.library.client.screens.project.branch.delete.DeleteBranchPopUpScreen;
+import org.kie.workbench.common.screens.library.client.screens.project.changerequest.list.ChangeRequestListPresenter;
 import org.kie.workbench.common.screens.library.client.screens.project.delete.DeleteProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.screens.project.rename.RenameProjectPopUpScreen;
 import org.kie.workbench.common.screens.library.client.settings.SettingsPresenter;
@@ -89,6 +90,12 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
     @Mock
     private AssetsScreen.View assetsView;
 
+    @Mock
+    private ChangeRequestListPresenter changeRequestsScreen;
+
+    @Mock
+    private ChangeRequestListPresenter.View changeRequestsView;
+
     @Mock
     private ContributorsListPresenter contributorsListScreen;
 
@@ -155,6 +162,7 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         promises = spy(new SyncPromises());
 
         when(assetsScreen.getView()).thenReturn(assetsView);
+        when(changeRequestsScreen.getView()).thenReturn(changeRequestsView);
 
         when(deleteProjectPopUpScreenInstance.get()).thenReturn(deleteProjectPopUpScreen);
         when(deleteBranchPopUpScreenInstance.get()).thenReturn(deleteBranchPopUpScreen);
@@ -166,6 +174,7 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         final ProjectScreen projectScreen = new ProjectScreen(this.view,
                                                               this.libraryPlaces,
                                                               this.assetsScreen,
+                                                              this.changeRequestsScreen,
                                                               this.contributorsListScreen,
                                                               this.projectMetrictsScreen,
                                                               this.projectController,
@@ -192,6 +201,7 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         doReturn(promises.resolve(false)).when(this.projectController).canBuildProject(any());
         doReturn(promises.resolve(false)).when(this.projectController).canDeployProject(any());
         doReturn(promises.resolve(false)).when(this.projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(this.projectController).canSubmitChangeRequest(any());
     }
 
     @Test
@@ -346,6 +356,21 @@ public class ProjectScreenTest extends ProjectScreenTestBase {
         }
     }
 
+    @Test
+    public void testSubmitChangeRequest() {
+        {
+            doReturn(promises.resolve(false)).when(this.projectController).canSubmitChangeRequest(any());
+            this.presenter.submitChangeRequest();
+            verify(this.libraryPlaces,
+                   never()).goToSubmitChangeRequestScreen();
+        }
+        {
+            doReturn(promises.resolve(true)).when(this.projectController).canSubmitChangeRequest(any());
+            this.presenter.submitChangeRequest();
+            verify(this.libraryPlaces).goToSubmitChangeRequestScreen();
+        }
+    }
+
     @Test
     public void testImportAsset() {
         {
