@@ -22,7 +22,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
-
 import javax.enterprise.event.Event;
 
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
@@ -35,6 +34,8 @@ import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.structure.client.security.OrganizationalUnitController;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
+import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.RemoveOrganizationalUnitEvent;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
@@ -51,11 +52,11 @@ import org.kie.workbench.common.screens.examples.model.ImportProject;
 import org.kie.workbench.common.screens.explorer.model.URIStructureExplorerModel;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectAssetListUpdated;
-import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportProjectsSetupEvent;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportRepositoryPopUpPresenter;
+import org.kie.workbench.common.screens.library.client.screens.project.changerequest.ChangeRequestUtils;
 import org.kie.workbench.common.screens.library.client.screens.project.close.CloseUnsavedProjectAssetsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.util.breadcrumb.LibraryBreadcrumbs;
 import org.kie.workbench.common.screens.library.client.util.breadcrumb.ProjectBranchBreadcrumb;
@@ -65,6 +66,7 @@ import org.mockito.Captor;
 import org.mockito.InOrder;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
+import org.slf4j.Logger;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
@@ -79,7 +81,6 @@ import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.ext.widgets.common.client.common.HasBusyIndicator;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mvp.Command;
-import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
@@ -92,23 +93,11 @@ import org.uberfire.workbench.model.impl.PartDefinitionImpl;
 
 import static java.util.Collections.emptyList;
 import static java.util.Collections.singleton;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.doAnswer;
-import static org.mockito.Mockito.doNothing;
-import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.inOrder;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.never;
-import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
+import static org.mockito.Mockito.*;
 
 @RunWith(MockitoJUnitRunner.class)
 public class LibraryPlacesTest {
@@ -191,7 +180,11 @@ public class LibraryPlacesTest {
     private LibraryBreadcrumbs libraryBreadcrumbs;
 
     @Mock
-    private LibraryInternalPreferences libraryInternalPreferences;
+    private OrganizationalUnitService organizationalUnitService;
+    private Caller<OrganizationalUnitService> organizationalUnitServiceCaller;
+
+    @Mock
+    private Logger logger;
 
     @Captor
     private ArgumentCaptor<WorkspaceProjectContextChangeEvent> projectContextChangeEventArgumentCaptor;
@@ -215,6 +208,7 @@ public class LibraryPlacesTest {
         libraryServiceCaller = new CallerMock<>(libraryService);
         vfsServiceCaller = new CallerMock<>(vfsService);
         repositoryServiceCaller = new CallerMock<>(repositoryService);
+        organizationalUnitServiceCaller = new CallerMock<>(organizationalUnitService);
 
         libraryBreadcrumbs = spy(new LibraryBreadcrumbs(breadcrumbs,
                                                         translationUtils,
@@ -240,10 +234,11 @@ public class LibraryPlacesTest {
                                               projectsSetupEvent,
                                               libraryBreadcrumbs,
                                               sessionInfo,
-                                              libraryInternalPreferences,
                                               repositoryServiceCaller,
                                               new SyncPromises(),
-                                              mock(OrganizationalUnitController.class)) {
+                                              mock(OrganizationalUnitController.class),
+                                              organizationalUnitServiceCaller,
+                                              logger) {
 
             @Override
             protected Map<String, List<String>> getParameterMap() {
@@ -292,16 +287,6 @@ public class LibraryPlacesTest {
         doReturn(pathPlaceRequest).when(libraryPlaces).createPathPlaceRequest(any());
 
         doReturn(importRepositoryPopUpPresenter).when(importRepositoryPopUpPresenters).get();
-
-        doAnswer(invocationOnMock -> {
-            invocationOnMock.getArgumentAt(0, ParameterizedCommand.class).execute(libraryInternalPreferences);
-            return null;
-        }).when(libraryInternalPreferences).load(any(ParameterizedCommand.class), any(ParameterizedCommand.class));
-
-        doAnswer(invocationOnMock -> {
-            invocationOnMock.getArgumentAt(0, Command.class).execute();
-            return null;
-        }).when(libraryInternalPreferences).save(any(Command.class), any(ParameterizedCommand.class));
     }
 
     @Test
@@ -484,6 +469,18 @@ public class LibraryPlacesTest {
         verify(libraryBreadcrumbs).setupForSpacesScreen();
     }
 
+    @Test
+    public void goToSpaceTest() {
+        doReturn(activeOrganizationalUnit).when(organizationalUnitService).getOrganizationalUnit(any());
+        doReturn(Optional.of(activeOrganizationalUnit)).when(projectContext).getActiveOrganizationalUnit();
+
+        libraryPlaces.nativeGoToSpace("space");
+
+        verify(projectContextChangeEvent, times(1)).fire(projectContextChangeEventArgumentCaptor.capture());
+        assertEquals(activeOrganizationalUnit, projectContextChangeEventArgumentCaptor.getValue().getOrganizationalUnit());
+        verify(libraryPlaces).goToLibrary();
+    }
+
     @Test
     public void goToAssetTest() {
         final ObservablePath path = mock(ObservablePath.class);
@@ -505,6 +502,35 @@ public class LibraryPlacesTest {
         assertNull(value.getPackage());
     }
 
+    @Test
+    public void goToSubmitChangeRequestScreenTest() {
+        final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.SUBMIT_CHANGE_REQUEST);
+        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
+        final LibraryPerspective libraryPerspective = mock(LibraryPerspective.class);
+
+        libraryPlaces.goToSubmitChangeRequestScreen();
+
+        verify(placeManager).goTo(part, libraryPerspective.getRootPanel());
+        verify(libraryBreadcrumbs).setupForSubmitChangeRequest(activeProject);
+    }
+
+    @Test
+    public void goToChangeRequestReviewScreenTest() {
+        final long changeRequestId = 1L;
+
+        final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.CHANGE_REQUEST_REVIEW);
+        placeRequest.addParameter(ChangeRequestUtils.CHANGE_REQUEST_ID_KEY,
+                                  String.valueOf(changeRequestId));
+
+        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
+        final LibraryPerspective libraryPerspective = mock(LibraryPerspective.class);
+
+        libraryPlaces.goToChangeRequestReviewScreen(changeRequestId);
+
+        verify(placeManager).goTo(part, libraryPerspective.getRootPanel());
+        verify(libraryBreadcrumbs).setupForChangeRequestReview(activeProject, changeRequestId);
+    }
+
     @Test
     public void goToAssetTestWithPackage() {
 
@@ -558,18 +584,18 @@ public class LibraryPlacesTest {
 
         doReturn(mock(OrganizationalUnit.class)).when(libraryService).getDefaultOrganizationalUnit();
 
-        final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.LIBRARY_SCREEN);
+        final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.ORGANIZATIONAL_UNITS_SCREEN);
         final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
         part.setSelectable(false);
 
         libraryPlaces.goToLibrary();
 
-        verify(libraryPlaces).closeLibraryPlaces();
+        verify(placeManager).closeAllPlaces();
         verify(placeManager).goTo(eq(part),
                                   any(PanelDefinition.class));
-        verify(libraryBreadcrumbs).setupForSpace(any());
+        verify(libraryBreadcrumbs).setupForSpacesScreen();
         verify(projectContextChangeEvent,
-               times(2)).fire(any(WorkspaceProjectContextChangeEvent.class));
+               times(1)).fire(any(WorkspaceProjectContextChangeEvent.class));
     }
 
     @Test
@@ -609,11 +635,9 @@ public class LibraryPlacesTest {
         libraryPlaces.goToLibrary();
 
         verify(libraryPlaces).closeLibraryPlaces();
-        verify(placeManager).goTo(eq(part),
-                                  any(PanelDefinition.class));
+        verify(placeManager).goTo(eq(part), any(PanelDefinition.class));
         verify(libraryBreadcrumbs).setupForSpace(activeOrganizationalUnit);
-        verify(projectContextChangeEvent,
-               never()).fire(any(WorkspaceProjectContextChangeEvent.class));
+        verify(projectContextChangeEvent, never()).fire(any(WorkspaceProjectContextChangeEvent.class));
     }
 
     @Test
@@ -703,13 +727,11 @@ public class LibraryPlacesTest {
                                                               activeRepository,
                                                               activeBranch,
                                                               mock(Module.class));
-        final Branch lastOpenedBranch = new Branch("master", mock(Path.class));
-        doReturn(Optional.of(lastOpenedBranch)).when(libraryInternalPreferences).getLastBranchOpened(project);
-        doReturn(activeProject).when(projectService).resolveProject(activeSpace, lastOpenedBranch);
+        doReturn(activeProject).when(projectService).resolveProject(activeSpace, activeBranch);
 
         libraryPlaces.goToProject(project);
 
-        verify(libraryPlaces).goToProject(project, lastOpenedBranch);
+        verify(libraryPlaces).goToProject(project, activeBranch);
         verify(projectContextChangeEvent).fire(any(WorkspaceProjectContextChangeEvent.class));
         verify(placeManager).closeAllPlaces();
     }
@@ -734,17 +756,13 @@ public class LibraryPlacesTest {
                                                               activeRepository,
                                                               activeBranch,
                                                               mock(Module.class));
-        final Branch lastOpenedBranch = new Branch("master", mock(Path.class));
         final Branch otherBranch = new Branch("other-branch", mock(Path.class));
 
-        doReturn(Optional.of(lastOpenedBranch)).when(libraryInternalPreferences).getLastBranchOpened(project);
         doReturn(activeProject).when(projectService).resolveProject(activeSpace, otherBranch);
 
         libraryPlaces.goToProject(project,
                                   otherBranch);
 
-        verify(libraryInternalPreferences).setLastBranchOpened(project, otherBranch);
-        verify(libraryInternalPreferences).save(any(Command.class), any());
         verify(libraryPlaces).goToProject(activeProject);
     }
 
@@ -755,14 +773,11 @@ public class LibraryPlacesTest {
                                                               activeBranch,
                                                               mock(Module.class));
 
-        doReturn(Optional.of(activeBranch)).when(libraryInternalPreferences).getLastBranchOpened(project);
         doReturn(activeProject).when(projectService).resolveProject(activeSpace, activeBranch);
 
         libraryPlaces.goToProject(project,
                                   activeBranch);
 
-        verify(libraryInternalPreferences, never()).setLastBranchOpened(any(), any());
-        verify(libraryInternalPreferences, never()).save(any(Command.class), any());
         verify(libraryPlaces).goToProject(activeProject);
     }
 
@@ -913,4 +928,32 @@ public class LibraryPlacesTest {
         verify(repositoryService).removeRepository(activeSpace, activeRepository.getAlias());
         verify(view).hideBusyIndicator();
     }
+
+    @Test
+    public void onOrganizationalUnitRemovedByLoggedUserTest() {
+        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+
+        libraryPlaces.onOrganizationalUnitRemoved(new RemoveOrganizationalUnitEvent(activeOrganizationalUnit, user.getIdentifier()));
+
+        verify(libraryPlaces, never()).goToOrganizationalUnits();
+    }
+
+    @Test
+    public void onOrganizationalUnitRemovedByOtherUserTest() {
+        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+
+        libraryPlaces.onOrganizationalUnitRemoved(new RemoveOrganizationalUnitEvent(activeOrganizationalUnit, "another-user"));
+
+        verify(libraryPlaces).goToOrganizationalUnits();
+    }
+
+    @Test
+    public void onOrganizationalUnitRemovedWithLibraryClosedTest() {
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(anyString());
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(any(PlaceRequest.class));
+
+        libraryPlaces.onOrganizationalUnitRemoved(new RemoveOrganizationalUnitEvent(activeOrganizationalUnit, "another-user"));
+
+        verify(libraryPlaces, never()).goToOrganizationalUnits();
+    }
 }
