@@ -16,20 +16,19 @@
 
 package org.kie.workbench.common.workbench.client.admin;
 
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SECURITY_MANAGEMENT;
-
 import java.util.HashMap;
 import java.util.Map;
 
 import javax.inject.Inject;
 
 import org.guvnor.common.services.shared.preferences.GuvnorPreferenceScopes;
+import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.security.shared.api.Group;
 import org.jboss.errai.security.shared.api.Role;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
+import org.kie.soup.commons.util.Sets;
+import org.kie.workbench.common.profile.api.preferences.ProfileService;
 import org.kie.workbench.common.widgets.client.handlers.workbench.configuration.LanguageConfigurationHandler;
 import org.kie.workbench.common.widgets.client.handlers.workbench.configuration.WorkbenchConfigurationPresenter;
 import org.kie.workbench.common.workbench.client.PerspectiveIds;
@@ -37,6 +36,7 @@ import org.kie.workbench.common.workbench.client.admin.resources.i18n.Preference
 import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.experimental.client.service.ClientExperimentalFeaturesRegistryService;
 import org.uberfire.ext.preferences.client.admin.page.AdminPage;
 import org.uberfire.ext.preferences.client.admin.page.AdminPageOptions;
 import org.uberfire.ext.security.management.api.AbstractEntityManager;
@@ -51,6 +51,10 @@ import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.model.ActivityResourceType;
 
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SECURITY_MANAGEMENT;
+
 public class DefaultAdminPageHelper {
 
     DefaultWorkbenchConstants constants = DefaultWorkbenchConstants.INSTANCE;
@@ -85,15 +89,21 @@ public class DefaultAdminPageHelper {
     @Inject
     private LanguageConfigurationHandler languageConfigurationHandler;
 
+    @Inject
+    private ClientExperimentalFeaturesRegistryService experimentalFeaturesService;
+
+    @Inject
+    Caller<ProfileService> profileService;
+
     public void setup() {
         setup(true,
               true,
               true);
     }
 
-    public void setup(boolean projectPreferencesEnabled,
-                      boolean libraryPreferencesEnabled,
-                      boolean artifactRepositoryPreferencesEnabled) {
+    public void setup(boolean libraryPreferencesEnabled,
+                      boolean artifactRepositoryPreferencesEnabled,
+                      boolean stunnerEnabled) {
         adminPage.addScreen("root",
                             constants.Settings());
         adminPage.setDefaultScreen("root");
@@ -102,25 +112,106 @@ public class DefaultAdminPageHelper {
         addArtifactsPerspective();
         addDataSourcePerspective();
         addDataSetPerspective();
-        addGlobalPreferences(projectPreferencesEnabled,
-                             libraryPreferencesEnabled,
+        addGlobalPreferences(libraryPreferencesEnabled,
                              artifactRepositoryPreferencesEnabled);
-        addGeneralSettings();
+        addGeneralPreferences();
+        addStunnerPreferences(stunnerEnabled);
+        addExperimentalPreferences();
+        addSSHKeys();
+        addProfilePreferences();
+        addDataTransferPerspective();
     }
 
-    private void addGeneralSettings() {
+    private void addDataTransferPerspective() {
+        boolean authorized = authorizationManager.authorize(
+            WorkbenchFeatures.ACCESS_DATA_TRANSFER,
+            sessionInfo.getIdentity());
+
+        if (!authorized) {
+            return;
+        }
+
+        adminPage.addTool(
+            "root",
+            constants.DataTransfer(),
+            new Sets.Builder().add("pficon").add("pficon-import").build(),
+            "services",
+            () -> {
+                Command cmd = () -> placeManager.goTo(PerspectiveIds.DATA_TRANSFER);
+                cmd.execute();
+                addAdminBreadcrumbs(PerspectiveIds.DATA_TRANSFER, constants.DataTransfer(), cmd);
+            });
+    }
+
+    private void addProfilePreferences() {
+        final boolean canEditProfilePreferences = authorizationManager.authorize(WorkbenchFeatures.EDIT_PROFILE_PREFERENCES,
+                                                                                 sessionInfo.getIdentity());
+        profileService.call((Boolean force) -> {
+            if (canEditProfilePreferences && !force) {
+                adminPage.addPreference("root",
+                        "ProfilePreferences",
+                        translationService.format(PreferencesConstants.ProfilePreferences_Title),
+                        new Sets.Builder().add("fa").add("fa-list").build(),
+                        "advanced",
+                        scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
+                        AdminPageOptions.WITH_BREADCRUMBS);
+            }
+        }).isForce();
+    }
+
+    private void addGeneralPreferences() {
         adminPage.addTool("root",
                           constants.Languages(),
-                          "fa-language",
-                          "general",
+                          new Sets.Builder().add("fa").add("fa-language").build(),
+                          "preferences",
                           () -> workbenchConfigurationPresenter.show(languageConfigurationHandler));
     }
 
+    private void addStunnerPreferences(boolean stunnerEnabled) {
+        if (stunnerEnabled) {
+            adminPage.addPreference("root",
+                                    "StunnerPreferences",
+                                    constants.StunnerDesignerPreferences(),
+                                    new Sets.Builder().add("fa").add("fa-object-group").build(),
+                                    "general",
+                                    scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
+                                    AdminPageOptions.WITH_BREADCRUMBS);
+        }
+    }
+
+    private void addExperimentalPreferences() {
+        if (hasAccessToPerspective(PerspectiveIds.EXPERIMENTAL_FEATURES) && experimentalFeaturesService.isExperimentalEnabled() && !experimentalFeaturesService.getFeaturesRegistry().getAllFeatures().isEmpty()) {
+            adminPage.addTool("root",
+                              constants.ExperimentalSettings(),
+                              new Sets.Builder().add("fa").add("fa-flask").build(),
+                              "advanced",
+                              () -> {
+                                  final Command accessExperimentals = () -> placeManager.goTo(PerspectiveIds.EXPERIMENTAL_FEATURES);
+                                  accessExperimentals.execute();
+                                  addAdminBreadcrumbs(PerspectiveIds.EXPERIMENTAL_FEATURES,
+                                                      constants.ExperimentalSettings(),
+                                                      accessExperimentals);
+                              });
+        }
+    }
+
+    private void addSSHKeys() {
+        adminPage.addTool("root",
+                          constants.SSHKeys(),
+                          new Sets.Builder().add("fa").add("fa-key").build(),
+                          "general",
+                          () -> {
+                              final Command accessSSHKeysEditor = () -> placeManager.goTo(PerspectiveIds.SSH_KEYS_EDITOR);
+                              accessSSHKeysEditor.execute();
+                              addAdminBreadcrumbs(PerspectiveIds.SSH_KEYS_EDITOR, constants.SSHKeys(), accessSSHKeysEditor);
+                          });
+    }
+
     private void addSecurityPerspective() {
         if (hasAccessToPerspective(PerspectiveIds.SECURITY_MANAGEMENT)) {
             adminPage.addTool("root",
                               constants.Roles(),
-                              "fa-unlock-alt",
+                              new Sets.Builder().add("fa").add("fa-unlock-alt").build(),
                               "security",
                               () -> {
                                   final Command accessRoles = () -> {
@@ -148,7 +239,7 @@ public class DefaultAdminPageHelper {
 
             adminPage.addTool("root",
                               constants.Groups(),
-                              "fa-users",
+                              new Sets.Builder().add("fa").add("fa-users").build(),
                               "security",
                               () -> {
                                   final Command accessGroups = () -> {
@@ -176,7 +267,7 @@ public class DefaultAdminPageHelper {
 
             adminPage.addTool("root",
                               constants.Users(),
-                              "fa-user",
+                              new Sets.Builder().add("fa").add("fa-user").build(),
                               "security",
                               () -> {
                                   final Command accessUsers = () -> {
@@ -208,7 +299,7 @@ public class DefaultAdminPageHelper {
         if (hasAccessToPerspective(PerspectiveIds.GUVNOR_M2REPO)) {
             adminPage.addTool("root",
                               constants.Artifacts(),
-                              "fa-download",
+                              new Sets.Builder().add("fa").add("fa-download").build(),
                               "perspectives",
                               () -> {
                                   final Command accessArtifacts = () -> placeManager.goTo(GUVNOR_M2REPO);
@@ -224,7 +315,7 @@ public class DefaultAdminPageHelper {
         if (hasAccessToPerspective(PerspectiveIds.DATASOURCE_MANAGEMENT)) {
             adminPage.addTool("root",
                               constants.DataSources(),
-                              "fa-database",
+                              new Sets.Builder().add("fa").add("fa-database").build(),
                               "perspectives",
                               () -> {
                                   final Command accessDataSources = () -> placeManager.goTo(PerspectiveIds.DATASOURCE_MANAGEMENT);
@@ -240,7 +331,7 @@ public class DefaultAdminPageHelper {
         if (hasAccessToPerspective(PerspectiveIds.DATASET_AUTHORING)) {
             adminPage.addTool("root",
                               constants.DataSets(),
-                              "fa-folder-open",
+                              new Sets.Builder().add("fa").add("fa-folder-open").build(),
                               "perspectives",
                               () -> {
                                   final Command accessDataSets = () -> placeManager.goTo(PerspectiveIds.DATASET_AUTHORING);
@@ -252,8 +343,7 @@ public class DefaultAdminPageHelper {
         }
     }
 
-    private void addGlobalPreferences(boolean projectPreferencesEnabled,
-                                      boolean libraryPreferencesEnabled,
+    private void addGlobalPreferences(boolean libraryPreferencesEnabled,
                                       boolean artifactRepositoryPreferencesEnabled) {
         final boolean canEditGlobalPreferences = authorizationManager.authorize(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES,
                                                                                 sessionInfo.getIdentity());
@@ -262,35 +352,45 @@ public class DefaultAdminPageHelper {
             return;
         }
 
-        if (projectPreferencesEnabled) {
-            adminPage.addPreference("root",
-                                    "ProjectPreferences",
-                                    translationService.format(PreferencesConstants.ProjectPreferences_Label),
-                                    "fa-pencil-square-o",
-                                    "preferences",
-                                    scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
-                                    AdminPageOptions.WITH_BREADCRUMBS);
-        }
-
         if (libraryPreferencesEnabled) {
             adminPage.addPreference("root",
                                     "LibraryPreferences",
                                     translationService.format(PreferencesConstants.LibraryPreferences_Title),
-                                    "fa-cubes",
+                                    new Sets.Builder().add("fa").add("fa-cubes").build(),
                                     "preferences",
                                     scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
                                     AdminPageOptions.WITH_BREADCRUMBS);
         }
 
-        if (artifactRepositoryPreferencesEnabled){
+        if (artifactRepositoryPreferencesEnabled) {
             adminPage.addPreference("root",
                                     "ArtifactRepositoryPreference",
                                     translationService.format(PreferencesConstants.ArtifactRepositoryPreferences_Title),
-                                    "fa-archive",
+                                    new Sets.Builder().add("fa").add("fa-archive").build(),
                                     "preferences",
                                     scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
                                     AdminPageOptions.WITH_BREADCRUMBS);
         }
+
+        adminPage.addPreference("root",
+                                "ManagePreferences",
+                                constants.ProcessAdministration(),
+                                new Sets.Builder().add("pficon").add("pficon-storage-domain").build(),
+                                "general",
+                                scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
+                                AdminPageOptions.WITH_BREADCRUMBS);
+
+        adminPage.addTool("root",
+                                constants.ServiceTasksAdministration(),
+                                new Sets.Builder().add("fa").add("fa-cogs").build(),
+                                "services",
+                                () -> {
+                                    final Command accessServiceTasks = () -> placeManager.goTo(PerspectiveIds.SERVICE_TASK_ADMIN);
+                                    accessServiceTasks.execute();
+                                    addAdminBreadcrumbs(PerspectiveIds.SERVICE_TASK_ADMIN,
+                                                        constants.ServiceTasksAdministration(),
+                                                        accessServiceTasks);
+                                });
     }
 
     private void addAdminBreadcrumbs(final String perspective,
