@@ -17,7 +17,6 @@
 package org.kie.workbench.common.workbench.client.docks;
 
 import java.util.Collection;
-
 import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
 import javax.enterprise.context.ApplicationScoped;
@@ -26,8 +25,7 @@ import javax.inject.Inject;
 
 import org.gwtbootstrap3.client.ui.constants.IconType;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
-import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
-import org.kie.workbench.common.widgets.client.docks.EditorDock;
+import org.kie.workbench.common.widgets.client.docks.AuthoringEditorDock;
 import org.kie.workbench.common.widgets.client.docks.WorkbenchDocksHandler;
 import org.kie.workbench.common.workbench.client.events.LayoutEditorFocusEvent;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
@@ -35,7 +33,6 @@ import org.uberfire.client.workbench.docks.UberfireDock;
 import org.uberfire.client.workbench.docks.UberfireDockPosition;
 import org.uberfire.client.workbench.docks.UberfireDockReadyEvent;
 import org.uberfire.client.workbench.docks.UberfireDocks;
-import org.uberfire.client.workbench.docks.UberfireDocksInteractionEvent;
 import org.uberfire.client.workbench.events.PlaceHiddenEvent;
 import org.uberfire.ext.layout.editor.client.LayoutComponentPaletteScreen;
 import org.uberfire.mvp.PlaceRequest;
@@ -43,7 +40,7 @@ import org.uberfire.mvp.impl.DefaultPlaceRequest;
 
 @ApplicationScoped
 public class AuthoringWorkbenchDocks
-        implements EditorDock {
+        implements AuthoringEditorDock {
 
     protected DefaultWorkbenchConstants constants = DefaultWorkbenchConstants.INSTANCE;
 
@@ -55,8 +52,6 @@ public class AuthoringWorkbenchDocks
 
     protected UberfireDock componentPaletteDock;
 
-    protected LibraryInternalPreferences libraryInternalPreferences;
-
     protected String currentPerspectiveIdentifier = null;
 
     protected boolean projectExplorerEnabled = true;
@@ -71,15 +66,14 @@ public class AuthoringWorkbenchDocks
 
     @Inject
     public AuthoringWorkbenchDocks(final UberfireDocks uberfireDocks,
-                                   final ManagedInstance<WorkbenchDocksHandler> installedHandlers,
-                                   final LibraryInternalPreferences libraryInternalPreferences) {
+                                   final ManagedInstance<WorkbenchDocksHandler> installedHandlers) {
         this.uberfireDocks = uberfireDocks;
         this.installedHandlers = installedHandlers;
-        this.libraryInternalPreferences = libraryInternalPreferences;
     }
 
     @PostConstruct
     public void initialize() {
+
         // Initializing the handlers
         installedHandlers.iterator().forEachRemaining(handler ->
                                                               handler.init(() -> setActiveHandler(handler)));
@@ -99,6 +93,7 @@ public class AuthoringWorkbenchDocks
         }
     }
 
+    @Override
     public void setup(String authoringPerspectiveIdentifier,
                       PlaceRequest projectExplorerPlaceRequest) {
         this.authoringPerspectiveIdentifier = authoringPerspectiveIdentifier;
@@ -119,10 +114,6 @@ public class AuthoringWorkbenchDocks
 
     public void setActiveHandler(WorkbenchDocksHandler handler) {
 
-        if (!isAuthoringActive()) {
-            return;
-        }
-
         // If there's an active handler let's check if it should refresh docks
         if (activeHandler != null) {
             if (activeHandler.equals(handler) && !activeHandler.shouldRefreshDocks()) {
@@ -138,6 +129,7 @@ public class AuthoringWorkbenchDocks
             uberfireDocks.hide(UberfireDockPosition.EAST,
                                currentPerspectiveIdentifier);
         } else {
+
             // first remove the existing docks
             if (activeDocks != null) {
                 uberfireDocks.remove(activeDocks);
@@ -157,6 +149,7 @@ public class AuthoringWorkbenchDocks
                 authoringPerspectiveIdentifier.equals(currentPerspectiveIdentifier);
     }
 
+    @Override
     public void hide() {
 
         if (componentPaletteEnabled) {
@@ -168,19 +161,11 @@ public class AuthoringWorkbenchDocks
         projectExplorerEnabled = false;
     }
 
+    @Override
     public void show() {
-
         uberfireDocks.show(UberfireDockPosition.WEST,
                            authoringPerspectiveIdentifier);
         projectExplorerEnabled = true;
-
-        libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
-                                            if (loadedLibraryInternalPreferences.isProjectExplorerExpanded()) {
-                                                expandProjectExplorer();
-                                            }
-                                        },
-                                        parameter -> {
-                                        });
     }
 
     public void expandProjectExplorer() {
@@ -189,6 +174,7 @@ public class AuthoringWorkbenchDocks
         }
     }
 
+    @Override
     public void expandAuthoringDock(final UberfireDock dockToOpen) {
         uberfireDocks.show(UberfireDockPosition.EAST, authoringPerspectiveIdentifier);
 
@@ -197,32 +183,6 @@ public class AuthoringWorkbenchDocks
         }
     }
 
-    public void projectExplorerExpandedEvent(@Observes final UberfireDocksInteractionEvent uberfireDocksInteractionEvent) {
-        final UberfireDock targetDock = uberfireDocksInteractionEvent.getTargetDock();
-        if (targetDock == null) {
-            return;
-        }
-        if (targetDock.equals(projectExplorerDock)) {
-            final UberfireDocksInteractionEvent.InteractionType interactionType = uberfireDocksInteractionEvent.getType();
-            if (interactionType.equals(UberfireDocksInteractionEvent.InteractionType.OPENED)) {
-                setProjectExplorerExpandedPreference(true);
-            } else if (interactionType.equals(UberfireDocksInteractionEvent.InteractionType.CLOSED)) {
-                setProjectExplorerExpandedPreference(false);
-            }
-        }
-    }
-
-    void setProjectExplorerExpandedPreference(final boolean expand) {
-        libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
-                                            if (expand != loadedLibraryInternalPreferences.isProjectExplorerExpanded()) {
-                                                loadedLibraryInternalPreferences.setProjectExplorerExpanded(expand);
-                                                loadedLibraryInternalPreferences.save();
-                                            }
-                                        },
-                                        error -> {
-                                        });
-    }
-
     private void refreshWestDocks(boolean showComponentPalette, UberfireDock dockToOpen) {
 
         if (showComponentPalette && !componentPaletteEnabled) {
