@@ -178,4 +178,8 @@ public interface DefaultWorkbenchConstants
     String AccessDataTransfer();
 
     String AccessDataTransferHelp();
+
+    String DisconnectedFromServer();
+
+    String CouldNotConnectToServer();
 }
