@@ -26,13 +26,38 @@ import org.uberfire.client.authz.EditorTreeProvider;
 import org.uberfire.client.authz.PerspectiveTreeProvider;
 import org.uberfire.mocks.MockInstanceImpl;
 
+import static org.kie.workbench.common.workbench.client.EditorIds.CASE_MODELLER;
 import static org.kie.workbench.common.workbench.client.EditorIds.GUIDED_DECISION_TREE;
 import static org.kie.workbench.common.workbench.client.EditorIds.GUIDED_SCORE_CARD;
+import static org.kie.workbench.common.workbench.client.EditorIds.SCENARIO_SIMULATION_DESIGNER;
 import static org.kie.workbench.common.workbench.client.EditorIds.STUNNER_DESIGNER;
 import static org.kie.workbench.common.workbench.client.EditorIds.XLS_SCORE_CARD;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.*;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMINISTRATION;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.APPS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.CONTENT_MANAGEMENT;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASET_AUTHORING;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.DATASOURCE_MANAGEMENT;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.EXECUTION_ERRORS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.HOME;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.JOBS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.LIBRARY;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PLUGIN_AUTHORING;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DASHBOARD;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_DEFINITIONS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROVISIONING;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SECURITY_MANAGEMENT;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SERVER_MANAGEMENT;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.SSH_KEYS_EDITOR;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS_ADMIN;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASK_DASHBOARD;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class PermissionTreeSetupTest {
@@ -86,8 +111,8 @@ public class PermissionTreeSetupTest {
                                                            eq("ProjectAuthoring"));
         verify(perspectiveTreeProvider).setPerspectiveName(eq(CONTENT_MANAGEMENT),
                                                            eq("Content_Management"));
-        verify(perspectiveTreeProvider).setPerspectiveName(eq(DEPLOYMENTS),
-                                                           eq("Process_Deployments"));
+        verify(perspectiveTreeProvider).setPerspectiveName(eq(PROVISIONING),
+                                                           eq("Provisioning"));
         verify(perspectiveTreeProvider).setPerspectiveName(eq(SERVER_MANAGEMENT),
                                                            eq("Rule_Deployments"));
         verify(perspectiveTreeProvider).setPerspectiveName(eq(PROCESS_DEFINITIONS),
@@ -114,7 +139,6 @@ public class PermissionTreeSetupTest {
     public void testConfigureTree_ExcludedPerspectives() {
         tree.configureTree();
 
-        verify(perspectiveTreeProvider).excludePerspectiveId(eq(AUTHORING));
         verify(perspectiveTreeProvider).excludePerspectiveId(eq("AuthoringPerspectiveNoContext"));
         verify(perspectiveTreeProvider).excludePerspectiveId(eq("FormDisplayPerspective"));
         verify(perspectiveTreeProvider).excludePerspectiveId(eq("Drools Tasks"));
@@ -125,8 +149,7 @@ public class PermissionTreeSetupTest {
         verify(perspectiveTreeProvider).excludePerspectiveId(eq("PreferencesCentralPerspective"));
         verify(perspectiveTreeProvider).excludePerspectiveId(eq(ADMINISTRATION));
         verify(perspectiveTreeProvider).excludePerspectiveId(eq(PLUGIN_AUTHORING));
-        verify(perspectiveTreeProvider).excludePerspectiveId(eq(SOCIAL_HOME));
-        verify(perspectiveTreeProvider).excludePerspectiveId(eq(SOCIAL_USER_HOME));
+        verify(perspectiveTreeProvider).excludePerspectiveId(eq(SSH_KEYS_EDITOR));
     }
 
     @Test
@@ -141,6 +164,10 @@ public class PermissionTreeSetupTest {
                                                   eq("XLSScoreCard"));
         verify(editorTreeProvider).registerEditor(eq(STUNNER_DESIGNER),
                                                   eq("StunnerDesigner"));
+        verify(editorTreeProvider).registerEditor(eq(CASE_MODELLER),
+                                                  eq("CaseModeller"));
+        verify(editorTreeProvider).registerEditor(eq(SCENARIO_SIMULATION_DESIGNER),
+                                                  eq("ScenarioSimulationEditor"));
     }
 
     @Test
