@@ -24,6 +24,8 @@ import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
+import org.kie.workbench.common.stunner.client.widgets.canvas.PreviewLienzoPanel;
 import org.kie.workbench.common.stunner.client.widgets.presenters.AbstractCanvasHandlerViewerTest;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionViewer;
 import org.kie.workbench.common.stunner.client.widgets.views.WidgetWrapperView;
@@ -33,15 +35,17 @@ import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.BaseCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasPanel;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.ContainmentAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.DockingAcceptorControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.MediatorsControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.connection.ConnectionAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.containment.ContainmentAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.docking.DockingAcceptorControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
+import org.kie.workbench.common.stunner.core.client.preferences.StunnerPreferencesRegistries;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.definition.adapter.AdapterManager;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionSetRuleAdapter;
@@ -49,6 +53,7 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
+import org.kie.workbench.common.stunner.core.preferences.StunnerPreferences;
 import org.kie.workbench.common.stunner.core.registry.definition.TypeDefinitionSetRegistry;
 import org.kie.workbench.common.stunner.core.rule.EmptyRuleSet;
 import org.kie.workbench.common.stunner.core.rule.RuleSet;
@@ -88,7 +93,8 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
     @Mock
     private ManagedInstance<CanvasCommandFactory> canvasCommandFactories;
 
-    private ManagedInstance<AbstractCanvas> canvases;
+    private ManagedInstance<WiresCanvas> canvases;
+    private ManagedInstance<CanvasPanel> canvasPanels;
 
     @Mock
     private ManagedInstance<BaseCanvasHandler> canvasHandlerFactories;
@@ -103,12 +109,15 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
     @Mock
     private EditorSession session;
 
+    @Mock
+    private PreviewLienzoPanel canvasPanel;
+
     @Mock
     private SessionViewer.SessionViewerCallback<Diagram> callback;
 
     @Mock
-    private ZoomControl<AbstractCanvas> zoomControl;
-    private ManagedInstance<ZoomControl<AbstractCanvas>> zoomControls;
+    private MediatorsControl<AbstractCanvas> mediatorsControl;
+    private ManagedInstance<MediatorsControl<AbstractCanvas>> mediatorsControls;
 
     @Mock
     private ConnectionAcceptorControl<AbstractCanvasHandler> connectionAcceptorControl;
@@ -161,20 +170,27 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
     @Mock
     private Object defSet;
 
+    @Mock
+    private StunnerPreferencesRegistries preferencesRegistries;
+
+    @Mock
+    StunnerPreferences stunnerPreferences;
+
     private SessionPreviewImpl preview;
 
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
         super.init();
-        zoomControls = new ManagedInstanceStub<>(zoomControl);
+        mediatorsControls = new ManagedInstanceStub<>(mediatorsControl);
         selectionControls = new ManagedInstanceStub<>(selectionControl);
         canvasCommandManagers = new ManagedInstanceStub<>(canvasCommandManager);
         canvases = new ManagedInstanceStub<>(canvas);
+        canvasPanels = new ManagedInstanceStub<>(canvasPanel);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(session.getCanvasHandler()).thenReturn(canvasHandler);
         when(session.getCanvas()).thenReturn(canvas);
-        when(session.getZoomControl()).thenReturn(zoomControl);
+        when(session.getMediatorsControl()).thenReturn(mediatorsControl);
         when(session.getConnectionAcceptorControl()).thenReturn(connectionAcceptorControl);
         when(session.getContainmentAcceptorControl()).thenReturn(containmentAcceptorControl);
         when(session.getDockingAcceptorControl()).thenReturn(dockingAcceptorControl);
@@ -186,6 +202,7 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
         when(diagram.getMetadata()).thenReturn(metaData);
         when(metaData.getDefinitionSetId()).thenReturn(DEFINITION_SET_ID);
         when(definitionUtils.getQualifier(eq(DEFINITION_SET_ID))).thenReturn(qualifier);
+        when(preferencesRegistries.get(DEFINITION_SET_ID, StunnerPreferences.class)).thenReturn(stunnerPreferences);
 
         when(customCanvasCommandFactoryInstance.get()).thenReturn(customCanvasCommandFactoryImplementation);
         when(defaultCanvasCommandFactoryInstance.get()).thenReturn(defaultCanvasCommandFactoryImplementation);
@@ -204,12 +221,14 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
                                               shapeManager,
                                               textPropertyProviderFactory,
                                               canvases,
+                                              canvasPanels,
                                               canvasHandlerFactories,
-                                              zoomControls,
+                                              mediatorsControls,
                                               selectionControls,
                                               canvasCommandFactories,
                                               canvasCommandManagers,
-                                              view);
+                                              view,
+                                              preferencesRegistries);
     }
 
     @Test
@@ -267,4 +286,9 @@ public class SessionPreviewImplTest extends AbstractCanvasHandlerViewerTest {
         final CanvasCommandFactory factory = preview.getCommandFactory();
         assertion.accept(factory);
     }
+
+    @Override
+    protected CanvasPanel getCanvasPanel() {
+        return canvasPanel;
+    }
 }
