@@ -27,12 +27,13 @@ import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.service.ClientDiagramServiceImpl;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
-import org.kie.workbench.common.stunner.core.client.session.command.event.SaveDiagramSessionCommandExecutedEvent;
+import org.kie.workbench.common.stunner.core.client.session.event.SessionDiagramSavedEvent;
 import org.kie.workbench.common.stunner.core.service.DiagramLookupService;
 import org.kie.workbench.common.stunner.project.client.resources.i18n.StunnerProjectClientMessages;
 import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
@@ -52,6 +53,7 @@ public class ClientProjectDiagramService extends ClientDiagramServiceImpl<Projec
 
     protected ClientProjectDiagramService() {
         this(null,
+             null,
              null,
              null,
              null);
@@ -59,10 +61,12 @@ public class ClientProjectDiagramService extends ClientDiagramServiceImpl<Projec
 
     @Inject
     public ClientProjectDiagramService(final ShapeManager shapeManager,
+                                       final SessionManager sessionManager,
                                        final Caller<ProjectDiagramService> diagramServiceCaller,
                                        final Caller<DiagramLookupService> diagramLookupServiceCaller,
-                                       final Event<SaveDiagramSessionCommandExecutedEvent> saveEvent) {
+                                       final Event<SessionDiagramSavedEvent> saveEvent) {
         super(shapeManager,
+              sessionManager,
               diagramServiceCaller,
               diagramLookupServiceCaller,
               saveEvent);
@@ -75,7 +79,6 @@ public class ClientProjectDiagramService extends ClientDiagramServiceImpl<Projec
                        final Package projectPkg,
                        final Optional<String> projectType,
                        final ServiceCallback<Path> callback) {
-
         diagramServiceCaller.call((RemoteCallback<Path>) callback::onSuccess,
                                   (message, throwable) -> {
                                       callback.onError(createOnErrorHandler(throwable, name, projectPkg));
@@ -96,7 +99,7 @@ public class ClientProjectDiagramService extends ClientDiagramServiceImpl<Projec
         diagramServiceCaller.call(v -> {
                                       updateClientMetadata(diagram);
                                       callback.onSuccess(diagram);
-                                      fireSavedEvent(diagram);
+                                      fireSavedEvent(sessionManager.getCurrentSession());
                                   },
                                   (message, throwable) -> {
                                       callback.onError(new ClientRuntimeError(throwable));
@@ -124,15 +127,14 @@ public class ClientProjectDiagramService extends ClientDiagramServiceImpl<Projec
 
     private ClientRuntimeError createOnErrorHandler(final Throwable throwable,
                                                     final String name,
-                                                    final Package projectPkg){
-      String FileAlreadyExistsExceptionClassName = "org.uberfire.java.nio.file.FileAlreadyExistsException";
-      if(throwable.getClass().getCanonicalName().equals(FileAlreadyExistsExceptionClassName)){
-          String message = translationService.getValue(StunnerProjectClientMessages.BUSINESS_PROCESS_ALREADY_EXISTS,
-                                                 projectPkg.getPackageName()+"."+name);
-          return new ClientRuntimeError(message, throwable);
-      }else{
-          return new ClientRuntimeError(throwable);
-      }
+                                                    final Package projectPkg) {
+        String FileAlreadyExistsExceptionClassName = "org.uberfire.java.nio.file.FileAlreadyExistsException";
+        if (throwable.getClass().getCanonicalName().equals(FileAlreadyExistsExceptionClassName)) {
+            String message = translationService.getValue(StunnerProjectClientMessages.BUSINESS_PROCESS_ALREADY_EXISTS,
+                                                         projectPkg.getPackageName() + "." + name);
+            return new ClientRuntimeError(message, throwable);
+        } else {
+            return new ClientRuntimeError(throwable);
+        }
     }
-
 }
