@@ -17,7 +17,7 @@
 package org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.processes;
 
 import org.eclipse.bpmn2.Process;
-import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.BaseConverterFactory;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.ConverterFactory;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.DefinitionsBuildingContext;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.ProcessPropertyWriter;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.PropertyWriterFactory;
@@ -40,7 +40,7 @@ public class RootProcessConverter {
 
     public RootProcessConverter(DefinitionsBuildingContext context,
                                 PropertyWriterFactory propertyWriterFactory,
-                                BaseConverterFactory converterFactory) {
+                                ConverterFactory converterFactory) {
         this.delegate = new ProcessConverterDelegate(converterFactory);
         this.context = context;
         this.propertyWriterFactory = propertyWriterFactory;
@@ -58,9 +58,10 @@ public class RootProcessConverter {
     private ProcessPropertyWriter convertProcessNode(Node<Definition<BPMNDiagram>, ?> node) {
         Process process = bpmn2.createProcess();
 
-        ProcessPropertyWriter p = propertyWriterFactory.of(process);
         BPMNDiagram definition = node.getContent().getDefinition();
 
+        ProcessPropertyWriter p = propertyWriterFactory.of(process);
+
         BaseDiagramSet diagramSet = definition.getDiagramSet();
 
         p.setName(diagramSet.getName().getValue());
@@ -72,6 +73,8 @@ public class RootProcessConverter {
         p.setAdHoc(diagramSet.getAdHoc().getValue());
         p.setDescription(diagramSet.getProcessInstanceDescription().getValue());
         p.setGlobalVariables(diagramSet.getGlobalVariables());
+        p.setDefaultImports(diagramSet.getImports().getValue().getDefaultImports());
+
         p.setExecutable(diagramSet.getExecutable().getValue());
         p.setSlaDueDate(diagramSet.getSlaDueDate());
 
