@@ -16,6 +16,9 @@
 
 package org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties;
 
+import java.util.ArrayList;
+import java.util.List;
+
 import org.eclipse.bpmn2.Process;
 import org.eclipse.bpmn2.di.BPMNEdge;
 import org.eclipse.bpmn2.di.BPMNShape;
@@ -23,11 +26,14 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.CustomElement;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.ProcessPropertyReader;
 import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseFileVariables;
 import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseIdPrefix;
 import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseRoles;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalVariables;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.DefaultImport;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables;
 import org.mockito.runners.MockitoJUnitRunner;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -42,7 +48,7 @@ import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunn
 @RunWith(MockitoJUnitRunner.class)
 public class ProcessPropertyWriterTest {
 
-    ProcessPropertyWriter p ;
+    ProcessPropertyWriter p;
     FlatVariableScope variableScope;
 
     @Before
@@ -136,6 +142,17 @@ public class ProcessPropertyWriterTest {
         assertThat(globalVariablesString).isEqualTo("GV1:Boolean,GV2:Boolean,GV3:Integer");
     }
 
+    @Test
+    public void processVariables() {
+        ProcessVariables processVariables = new ProcessVariables("GV1:Boolean:true,GV2:Boolean:true,GV3:Integer:false");
+        p.setProcessVariables(processVariables);
+
+        final ProcessPropertyReader pp = new ProcessPropertyReader(
+                p.getProcess(), p.getBpmnDiagram(), p.getShape(), 1.0);
+        String processVariablesString =  pp.getProcessVariables();
+        assertThat(processVariablesString).isEqualTo("GV1:Boolean:true,GV2:Boolean:true,GV3:Integer:false");
+    }
+
     @Test
     public void slaDueDate() {
         SLADueDate slaDueDate = new SLADueDate("12/25/1983");
@@ -144,6 +161,18 @@ public class ProcessPropertyWriterTest {
         assertThat(slaDueDateString).isEqualTo("<![CDATA[12/25/1983]]>");
     }
 
+    @Test
+    public void defaultImports() {
+        List<DefaultImport> defaultImports = new ArrayList<>();
+        defaultImports.add(new DefaultImport("className1"));
+        defaultImports.add(new DefaultImport("className2"));
+        defaultImports.add(new DefaultImport("className3"));
+
+        p.setDefaultImports(defaultImports);
+
+        assertEquals(defaultImports, CustomElement.defaultImports.of(p.getProcess()).get());
+    }
+
     @Test
     public void testSetDocumentationNotEmpty() {
         p.setDocumentation("DocumentationValue");
