@@ -1,5 +1,5 @@
 /*
- * Copyright 2018 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2019 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,8 +23,7 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.assertj.core.api.Assertions.assertThat;
 
 public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEventTest<IntermediateSignalEventCatching> {
 
@@ -35,15 +34,18 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     private static final String EMPTY_SUBPROCESS_LEVEL_EVENT_ID = "FFA6848C-267E-46FA-806B-DF1F38BA3A3B";
     private static final String FILLED_SUBPROCESS_LEVEL_EVENT_ID = "85C587F5-5C3A-4F48-B21B-887CF19FF3F2";
 
-    private static final String EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID = "3DC11DED-4E87-4ECD-B2DA-F8AAB279C372";
-    private static final String FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID = "A1A7E835-EBDA-4727-AAA9-7E230541B0F8";
-    private static final String EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID = "C9F04A4E-107B-41B0-8A38-2CA7CD8D327C";
-    private static final String FILLED_WITH_INCOME_TOP_LEVEL_EVENT_ID = "4257742E-5360-4D20-968A-FE14E68D9991";
+    private static final String EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID = "3DC11DED-4E87-4ECD-B2DA-F8AAB279C372";
+    private static final String FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID = "A1A7E835-EBDA-4727-AAA9-7E230541B0F8";
+    private static final String EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID = "C9F04A4E-107B-41B0-8A38-2CA7CD8D327C";
+    private static final String FILLED_WITH_EDGES_TOP_LEVEL_EVENT_ID = "4257742E-5360-4D20-968A-FE14E68D9991";
 
     private static final String SLA_DUE_DATE = "12/25/1983";
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 23;
 
+    public CatchingIntermediateSignalEventTest() throws Exception {
+    }
+
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
@@ -52,13 +54,13 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
         final String EVENT_REF = "signal1";
         final String EVENT_DATA_OUTPUT = "||signal01:String||[dout]signal01->processGlobalVar";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching filledTopEvent = getCatchingIntermediateNodeById(diagram,
                                                                                          FILLED_TOP_LEVEL_EVENT_ID,
                                                                                          HAS_NO_INCOME_EDGE,
-                                                                                         HAS_OUTGOING_EDGE);
+                                                                                         ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEvent.getGeneral(), EVENT_NAME, EVENT_DOCUMENTATION);
         assertSignalEventExecutionSet(filledTopEvent.getExecutionSet(), EVENT_REF, CANCELLING, SLA_DUE_DATE);
         assertDataIOSet(filledTopEvent.getDataIOSet(), EVENT_DATA_OUTPUT);
@@ -67,13 +69,13 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     @Test
     @Override
     public void testUnmarshallTopLevelEmptyEventProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching emptyTopEvent = getCatchingIntermediateNodeById(diagram,
                                                                                         EMPTY_TOP_LEVEL_EVENT_ID,
                                                                                         HAS_NO_INCOME_EDGE,
-                                                                                        HAS_OUTGOING_EDGE);
+                                                                                        ZERO_OUTGOING_EDGES);
         assertGeneralSet(emptyTopEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptyTopEvent.getExecutionSet(), EMPTY_VALUE, CANCELLING, EMPTY_VALUE);
         assertDataIOSet(emptyTopEvent.getDataIOSet(), EMPTY_VALUE);
@@ -87,13 +89,13 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
         final String EVENT_REF = "signal3";
         final String EVENT_DATA_OUTPUT = "||signal03:String||[dout]signal03->processGlobalVar";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching filledSubprocessEvent = getCatchingIntermediateNodeById(diagram,
                                                                                                 FILLED_SUBPROCESS_LEVEL_EVENT_ID,
                                                                                                 HAS_NO_INCOME_EDGE,
-                                                                                                HAS_OUTGOING_EDGE);
+                                                                                                ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEvent.getGeneral(), EVENT_NAME, EVENT_DOCUMENTATION);
         assertSignalEventExecutionSet(filledSubprocessEvent.getExecutionSet(), EVENT_REF, CANCELLING, SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessEvent.getDataIOSet(), EVENT_DATA_OUTPUT);
@@ -102,13 +104,13 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     @Test
     @Override
     public void testUnmarshallSubprocessLevelEventEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching emptySubprocessEvent = getCatchingIntermediateNodeById(diagram,
                                                                                                EMPTY_SUBPROCESS_LEVEL_EVENT_ID,
                                                                                                HAS_NO_INCOME_EDGE,
-                                                                                               HAS_OUTGOING_EDGE);
+                                                                                               ZERO_OUTGOING_EDGES);
         assertGeneralSet(emptySubprocessEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptySubprocessEvent.getExecutionSet(), EMPTY_VALUE, CANCELLING, EMPTY_VALUE);
         assertDataIOSet(emptySubprocessEvent.getDataIOSet(), EMPTY_VALUE);
@@ -116,19 +118,19 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallTopLevelEventWithEdgesFilledProperties() throws Exception {
+    public void testUnmarshallTopLevelEventWithEdgesFilledProperties() {
         final String EVENT_NAME = "signal name ~`!@#$%^&*()_+=-{}|\\][:\";'?><,./";
         final String EVENT_DOCUMENTATION = "signal documentation\n ~`!@#$%^&*()_+=-{}|\\][:\";'?><,./";
         final String EVENT_REF = "signal2";
         final String EVENT_DATA_OUTPUT = "||signal02:String||[dout]signal02->processGlobalVar";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching filledSubprocessEvent = getCatchingIntermediateNodeById(diagram,
-                                                                                                FILLED_WITH_INCOME_TOP_LEVEL_EVENT_ID,
+                                                                                                FILLED_WITH_EDGES_TOP_LEVEL_EVENT_ID,
                                                                                                 HAS_INCOME_EDGE,
-                                                                                                HAS_OUTGOING_EDGE);
+                                                                                                TWO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEvent.getGeneral(), EVENT_NAME, EVENT_DOCUMENTATION);
         assertSignalEventExecutionSet(filledSubprocessEvent.getExecutionSet(), EVENT_REF, CANCELLING, SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessEvent.getDataIOSet(), EVENT_DATA_OUTPUT);
@@ -136,14 +138,14 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallTopLevelEventWithEdgesEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+    public void testUnmarshallTopLevelEventWithEdgesEmptyProperties() {
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching emptyEvent = getCatchingIntermediateNodeById(diagram,
-                                                                                     EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID,
+                                                                                     EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID,
                                                                                      HAS_INCOME_EDGE,
-                                                                                     HAS_OUTGOING_EDGE);
+                                                                                     TWO_OUTGOING_EDGES);
         assertGeneralSet(emptyEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptyEvent.getExecutionSet(), EMPTY_VALUE, CANCELLING, EMPTY_VALUE);
         assertDataIOSet(emptyEvent.getDataIOSet(), EMPTY_VALUE);
@@ -151,14 +153,14 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallSubprocessLevelEventWithEdgesEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+    public void testUnmarshallSubprocessLevelEventWithEdgesEmptyProperties() {
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching emptySubprocessEvent = getCatchingIntermediateNodeById(diagram,
-                                                                                               EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID,
+                                                                                               EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID,
                                                                                                HAS_INCOME_EDGE,
-                                                                                               HAS_OUTGOING_EDGE);
+                                                                                               TWO_OUTGOING_EDGES);
         assertGeneralSet(emptySubprocessEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptySubprocessEvent.getExecutionSet(), EMPTY_VALUE, CANCELLING, EMPTY_VALUE);
         assertDataIOSet(emptySubprocessEvent.getDataIOSet(), EMPTY_VALUE);
@@ -166,19 +168,19 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallSubprocessLevelEventWithEdgesFilledProperties() throws Exception {
+    public void testUnmarshallSubprocessLevelEventWithEdgesFilledProperties() {
         final String EVENT_NAME = "signal name ~`!@#$%^&*()_+=-{}|\\][:\";'?><,./";
         final String EVENT_DOCUMENTATION = "signal documentation\n ~`!@#$%^&*()_+=-{}|\\][:\";'?><,./";
         final String EVENT_REF = "signal4";
         final String EVENT_DATA_OUTPUT = "||signal04:String||[dout]signal04->processGlobalVar";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventCatching filledSubprocessEvent = getCatchingIntermediateNodeById(diagram,
-                                                                                                FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID,
+                                                                                                FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID,
                                                                                                 HAS_INCOME_EDGE,
-                                                                                                HAS_OUTGOING_EDGE);
+                                                                                                TWO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEvent.getGeneral(), EVENT_NAME, EVENT_DOCUMENTATION);
         assertSignalEventExecutionSet(filledSubprocessEvent.getExecutionSet(), EVENT_REF, CANCELLING, SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessEvent.getDataIOSet(), EVENT_DATA_OUTPUT);
@@ -195,8 +197,8 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     }
 
     @Override
-    String getFilledTopLevelEventId() {
-        return FILLED_TOP_LEVEL_EVENT_ID;
+    String[] getFilledTopLevelEventIds() {
+        return new String[]{FILLED_TOP_LEVEL_EVENT_ID};
     }
 
     @Override
@@ -205,8 +207,8 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     }
 
     @Override
-    String getFilledSubprocessLevelEventId() {
-        return FILLED_SUBPROCESS_LEVEL_EVENT_ID;
+    String[] getFilledSubprocessLevelEventIds() {
+        return new String[]{FILLED_SUBPROCESS_LEVEL_EVENT_ID};
     }
 
     @Override
@@ -215,31 +217,31 @@ public class CatchingIntermediateSignalEventTest extends CatchingIntermediateEve
     }
 
     @Override
-    String getFilledTopLevelEventWithEdgesId() {
-        return FILLED_WITH_INCOME_TOP_LEVEL_EVENT_ID;
+    String[] getFilledTopLevelEventWithEdgesIds() {
+        return new String[]{FILLED_WITH_EDGES_TOP_LEVEL_EVENT_ID};
     }
 
     @Override
     String getEmptyTopLevelEventWithEdgesId() {
-        return EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID;
+        return EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID;
     }
 
     @Override
-    String getFilledSubprocessLevelEventWithEdgesId() {
-        return FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID;
+    String[] getFilledSubprocessLevelEventWithEdgesIds() {
+        return new String[]{FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID};
     }
 
     @Override
     String getEmptySubprocessLevelEventWithEdgesId() {
-        return EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID;
+        return EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID;
     }
 
     private void assertSignalEventExecutionSet(CancellingSignalEventExecutionSet executionSet, String eventName, boolean isCancelling, String slaDueDate) {
-        assertNotNull(executionSet);
-        assertNotNull(executionSet.getSignalRef());
-        assertEquals(eventName, executionSet.getSignalRef().getValue());
+        assertThat(executionSet).isNotNull();
+        assertThat(executionSet.getSignalRef()).isNotNull();
+        assertThat(executionSet.getSignalRef().getValue()).isEqualTo(eventName);
 
         assertEventCancelActivity(executionSet, isCancelling);
-        assertTimerEventSlaDueDate(executionSet, slaDueDate);
+        assertEventSlaDueDate(executionSet, slaDueDate);
     }
 }
