@@ -32,7 +32,6 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.client.components.palette.BPMNCategoryDefinitionProvider;
 import org.kie.workbench.common.stunner.bpmn.client.documentation.decorator.PropertyDecorators;
 import org.kie.workbench.common.stunner.bpmn.client.shape.factory.BPMNShapeFactory;
-import org.kie.workbench.common.stunner.bpmn.client.workitem.WorkItemDefinitionClientRegistry;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNCategories;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.EmbeddedSubprocess;
@@ -51,6 +50,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Package;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.ProcessInstanceDescription;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Version;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.Imports;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.RectangleDimensionsSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
@@ -73,6 +73,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleIn
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceCompletionCondition;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceDataInput;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceDataOutput;
+import org.kie.workbench.common.stunner.bpmn.definition.property.task.MultipleInstanceExecutionMode;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.OnEntryAction;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.OnExitAction;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTypeListValue;
@@ -162,9 +163,9 @@ public class ClientBPMNDocumentationServiceTest {
     public static final String ON_ENTRY_CAPTION = "ONENTRY_CAPTION";
     public static final String TEMPLATE = "documentationTemplate";
     public static final String ASSIGNEMNTS = "assignemnts";
-    private static final String VARIABLES = "PV1:java.lang.String,PV2:java.lang.Boolean";
-    private static final String GLOBAL_VARIABLES = "GL1:java.lang.String,GL2:java.lang.Boolean";
-    private static final String SUB_PROCESS_VARIABLES = "SUBPV1:java.lang.String,SUBPV2:java.lang.Boolean";
+    private static final String VARIABLES = "PV1:java.lang.String:false,PV2:java.lang.Boolean:false";
+    private static final String GLOBAL_VARIABLES = "GL1:java.lang.String:false,GL2:java.lang.Boolean:false";
+    private static final String SUB_PROCESS_VARIABLES = "SUBPV1:java.lang.String:false,SUBPV2:java.lang.Boolean:false";
     private static final String ISASYNC_CAPTION = "ISASYNC_CAPTION";
     private static final String ON_EXIT_CAPTION = "ONEXIT_CAPTION";
     private static final String ICON_HTML = "icon image";
@@ -200,9 +201,6 @@ public class ClientBPMNDocumentationServiceTest {
     @Mock
     private ClientTranslationService translationService;
 
-    @Mock
-    private WorkItemDefinitionClientRegistry workItemDefinitionClientRegistry;
-
     @Mock
     private Diagram diagram;
 
@@ -305,6 +303,7 @@ public class ClientBPMNDocumentationServiceTest {
                                     adHoc,
                                     processInstanceDescription,
                                     globalVariables,
+                                    new Imports(),
                                     executable,
                                     slaDueDate);
         //ProcessData
@@ -336,6 +335,7 @@ public class ClientBPMNDocumentationServiceTest {
                                                          new CreatedBy(),
                                                          new AdHocAutostart(true),
                                                          new IsMultipleInstance(false),
+                                                         new MultipleInstanceExecutionMode(),
                                                          new MultipleInstanceCollectionInput(),
                                                          new MultipleInstanceDataInput(),
                                                          new MultipleInstanceCollectionOutput(),
@@ -361,7 +361,8 @@ public class ClientBPMNDocumentationServiceTest {
                                                                                                                                                                 SCRIPT))),
                                                                                        new OnExitAction(new ScriptTypeListValue().addValue(new ScriptTypeValue(LANGUAGE,
                                                                                                                                                                SCRIPT))),
-                                                                                       new IsAsync(false)),
+                                                                                       new IsAsync(false),
+                                                                                       new SLADueDate()),
                                                     new ProcessData(SUB_PROCESS_VARIABLES));
 
         nodes = Arrays.asList(createNode(bpmnDiagram), createNode(userTask), createNode(embeddedSubprocess));
@@ -370,7 +371,6 @@ public class ClientBPMNDocumentationServiceTest {
         when(graph.nodes()).thenReturn(nodes);
 
         when(mustacheTemplateRenderer.render(eq(TEMPLATE), any(BPMNDocumentation.class))).thenReturn(RENDERED_DOC);
-        when(workItemDefinitionClientRegistry.getRegistry()).thenReturn(workItemDefinitionClientRegistry);
         when(decorators.getDecorator(anyString())).thenReturn(Optional.empty());
 
         //adapters mock
@@ -448,7 +448,7 @@ public class ClientBPMNDocumentationServiceTest {
                                                     categoryDefinitionProvider,
                                                     glyphRenderer,
                                                     translationService,
-                                                    workItemDefinitionClientRegistry,
+                                                    null,
                                                     decorators);
     }
 
@@ -491,19 +491,30 @@ public class ClientBPMNDocumentationServiceTest {
         assertEquals(dataTotal.getTotalVariables(), 6, 0);
 
         //assert sorting based on the variables names
-        final KeyValue[] variables = dataTotal.getVariables();
-        assertEquals(variables[0].getKey(), "GL1");
-        assertEquals(variables[0].getValue(), String.class.getName());
-        assertEquals(variables[1].getKey(), "GL2");
-        assertEquals(variables[1].getValue(), Boolean.class.getName());
-        assertEquals(variables[2].getKey(), "PV1");
-        assertEquals(variables[2].getValue(), String.class.getName());
-        assertEquals(variables[3].getKey(), "PV2");
-        assertEquals(variables[3].getValue(), Boolean.class.getName());
-        assertEquals(variables[4].getKey(), "SUBPV1");
-        assertEquals(variables[4].getValue(), String.class.getName());
-        assertEquals(variables[5].getKey(), "SUBPV2");
-        assertEquals(variables[5].getValue(), Boolean.class.getName());
+        final ProcessVariablesTotal.VariableTriplets[] variables = dataTotal.getVariablesAsTriplets();
+        assertEquals(variables[0].name, "GL1");
+        assertEquals(variables[0].type, String.class.getName());
+        assertEquals(variables[0].kpi, "false");
+
+        assertEquals(variables[1].name, "GL2");
+        assertEquals(variables[1].type, Boolean.class.getName());
+        assertEquals(variables[1].kpi, "false");
+
+        assertEquals(variables[2].name, "PV1");
+        assertEquals(variables[2].type, String.class.getName());
+        assertEquals(variables[2].kpi, "false");
+
+        assertEquals(variables[3].name, "PV2");
+        assertEquals(variables[3].type, Boolean.class.getName());
+        assertEquals(variables[3].kpi, "false");
+
+        assertEquals(variables[4].name, "SUBPV1");
+        assertEquals(variables[4].type, String.class.getName());
+        assertEquals(variables[4].kpi, "false");
+
+        assertEquals(variables[5].name, "SUBPV2");
+        assertEquals(variables[5].type, Boolean.class.getName());
+        assertEquals(variables[5].kpi, "false");
 
         final ElementTotal[] totals = bpmnDocumentation.getElementsDetails().getTotals();
         assertEquals(totals.length, 2);
