@@ -21,13 +21,13 @@ import java.util.List;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.stunner.bpmn.backend.workitem.service.WorkItemDefinitionBackendService;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.AdHoc;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.DiagramSet;
 import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
 import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTaskFactory;
+import org.kie.workbench.common.stunner.bpmn.workitem.service.WorkItemDefinitionLookupService;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.command.Command;
@@ -53,6 +53,7 @@ import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
@@ -89,7 +90,7 @@ public class CaseGraphFactoryImplTest {
     private ServiceTaskFactory serviceTaskFactory;
 
     @Mock
-    private WorkItemDefinitionBackendService workItemDefinitionService;
+    private WorkItemDefinitionLookupService workItemDefinitionService;
 
     @Mock
     private Node diagramNode;
@@ -136,7 +137,7 @@ public class CaseGraphFactoryImplTest {
         when(registry.getDefinitionAdapter(ServiceTask.class)).thenReturn(adapter);
         when(adapter.getId(milestone)).thenReturn(DefinitionId.build(MILESTONE_ID));
         when(factoryManager.newElement(anyString(),
-                                       eq(BPMNDiagramImpl.class))).thenReturn(diagramNode);
+                                       eq(getDefinitionId(BPMNDiagramImpl.class)))).thenReturn(diagramNode);
         when(factoryManager.newElement(anyString(),
                                        eq(MILESTONE_ID))).thenReturn(milestoneNode);
         when(diagramNode.getContent()).thenReturn(diagramContent);
