@@ -16,45 +16,51 @@
 
 package org.kie.workbench.common.stunner.bpmn.project.client.editor;
 
+import java.util.function.Consumer;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
-import com.google.gwt.user.client.ui.Widget;
-import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactory;
+import org.jboss.errai.common.client.api.Caller;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.workbench.common.stunner.bpmn.integration.client.IntegrationHandler;
+import org.kie.workbench.common.stunner.bpmn.integration.client.IntegrationHandlerProvider;
 import org.kie.workbench.common.stunner.bpmn.project.client.type.BPMNDiagramResourceType;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenterFactory;
+import org.kie.workbench.common.stunner.bpmn.qualifiers.BPMN;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
 import org.kie.workbench.common.stunner.core.client.annotation.DiagramEditor;
-import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
-import org.kie.workbench.common.stunner.core.client.session.command.impl.SessionCommandFactory;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientFullSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientReadOnlySession;
-import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
+import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
+import org.kie.workbench.common.stunner.kogito.client.editor.event.OnDiagramFocusEvent;
+import org.kie.workbench.common.stunner.kogito.client.editor.event.OnDiagramLoseFocusEvent;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
-import org.kie.workbench.common.stunner.project.client.editor.ProjectDiagramEditorMenuItemsBuilder;
-import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramFocusEvent;
-import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramLoseFocusEvent;
 import org.kie.workbench.common.stunner.project.client.screens.ProjectMessagesListener;
 import org.kie.workbench.common.stunner.project.client.service.ClientProjectDiagramService;
+import org.kie.workbench.common.stunner.project.service.ProjectDiagramResourceService;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.annotations.WorkbenchEditor;
 import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartTitleDecoration;
 import org.uberfire.client.annotations.WorkbenchPartView;
-import org.uberfire.client.mvp.PlaceManager;
-import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
-import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
+import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnFocus;
 import org.uberfire.lifecycle.OnLostFocus;
 import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.lifecycle.OnOpen;
 import org.uberfire.lifecycle.OnStartup;
+import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.Menus;
 
 @Dependent
@@ -64,37 +70,51 @@ public class BPMNDiagramEditor extends AbstractProjectDiagramEditor<BPMNDiagramR
 
     public static final String EDITOR_ID = "BPMNDiagramEditor";
 
+    private final IntegrationHandlerProvider integrationHandlerProvider;
+    private boolean isMigrating = false;
+    private Consumer<Boolean> saveCallback;
+
     @Inject
     public BPMNDiagramEditor(final View view,
-                             final PlaceManager placeManager,
-                             final ErrorPopupPresenter errorPopupPresenter,
-                             final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
-                             final SavePopUpPresenter savePopUpPresenter,
-                             final BPMNDiagramResourceType resourceType,
-                             final ClientProjectDiagramService projectDiagramServices,
-                             final SessionManager sessionManager,
-                             final SessionPresenterFactory<Diagram, AbstractClientReadOnlySession, AbstractClientFullSession> sessionPresenterFactory,
-                             final SessionCommandFactory sessionCommandFactory,
-                             final ProjectDiagramEditorMenuItemsBuilder menuItemsBuilder,
+                             final TextEditorView xmlEditorView,
+                             final ManagedInstance<SessionEditorPresenter<EditorSession>> editorPresenter,
+                             final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerPresenter,
                              final Event<OnDiagramFocusEvent> onDiagramFocusEvent,
                              final Event<OnDiagramLoseFocusEvent> onDiagramLostFocusEvent,
+                             final Event<NotificationEvent> notificationEvent,
+                             final ErrorPopupPresenter errorPopupPresenter,
+                             final DiagramClientErrorHandler diagramClientErrorHandler,
+                             final @BPMN DocumentationView documentationView,
+                             final BPMNDiagramResourceType resourceType,
+                             final BPMNProjectEditorMenuSessionItems menuSessionItems,
                              final ProjectMessagesListener projectMessagesListener,
-                             final DiagramClientErrorHandler diagramClientErrorHandler) {
+                             final ClientTranslationService translationService,
+                             final ClientProjectDiagramService projectDiagramServices,
+                             final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller,
+                             final IntegrationHandlerProvider integrationHandlerProvider) {
         super(view,
-              placeManager,
-              errorPopupPresenter,
-              changeTitleNotificationEvent,
-              savePopUpPresenter,
-              resourceType,
-              projectDiagramServices,
-              sessionManager,
-              sessionPresenterFactory,
-              sessionCommandFactory,
-              menuItemsBuilder,
+              xmlEditorView,
+              editorPresenter,
+              viewerPresenter,
               onDiagramFocusEvent,
               onDiagramLostFocusEvent,
+              notificationEvent,
+              errorPopupPresenter,
+              diagramClientErrorHandler,
+              documentationView,
+              resourceType,
+              menuSessionItems,
               projectMessagesListener,
-              diagramClientErrorHandler);
+              translationService,
+              projectDiagramServices,
+              projectDiagramResourceServiceCaller);
+        this.integrationHandlerProvider = integrationHandlerProvider;
+    }
+
+    @Override
+    public void init() {
+        super.init();
+        integrationHandlerProvider.getIntegrationHandler().ifPresent(integrationHandler -> getBPMNSessionItems().setOnMigrate(() -> onMigrate(integrationHandler)));
     }
 
     @OnStartup
@@ -105,17 +125,7 @@ public class BPMNDiagramEditor extends AbstractProjectDiagramEditor<BPMNDiagramR
     }
 
     @Override
-    protected int getCanvasWidth() {
-        return (int) BPMNGraphFactory.GRAPH_DEFAULT_WIDTH;
-    }
-
-    @Override
-    protected int getCanvasHeight() {
-        return (int) BPMNGraphFactory.GRAPH_DEFAULT_HEIGHT;
-    }
-
-    @Override
-    protected String getEditorIdentifier() {
+    public String getEditorIdentifier() {
         return EDITOR_ID;
     }
 
@@ -125,6 +135,7 @@ public class BPMNDiagramEditor extends AbstractProjectDiagramEditor<BPMNDiagramR
     }
 
     @OnClose
+    @Override
     public void onClose() {
         super.doClose();
     }
@@ -150,17 +161,48 @@ public class BPMNDiagramEditor extends AbstractProjectDiagramEditor<BPMNDiagramR
     }
 
     @WorkbenchMenu
-    public Menus getMenus() {
-        return super.getMenus();
+    public void getMenus(final Consumer<Menus> menusConsumer) {
+        super.getMenus(menusConsumer);
     }
 
     @WorkbenchPartView
-    public Widget getWidget() {
-        return getView().asWidget();
+    public IsWidget getWidget() {
+        return super.getWidget();
     }
 
     @OnMayClose
     public boolean onMayClose() {
         return super.mayClose(getCurrentDiagramHash());
     }
+
+    protected void onMigrate(IntegrationHandler integrationHandler) {
+        final ParameterizedCommand<Consumer<Boolean>> saveCommand = saveCallback -> {
+            isMigrating = true;
+            this.saveCallback = saveCallback;
+            BPMNDiagramEditor.super.save();
+        };
+        integrationHandler.migrateFromStunnerToJBPMDesigner(versionRecordManager.getCurrentPath(), place, isDirty(getCurrentContentHash()), saveCommand);
+    }
+
+    @Override
+    protected void onSaveSuccess() {
+        super.onSaveSuccess();
+        if (isMigrating) {
+            isMigrating = false;
+            saveCallback.accept(true);
+        }
+    }
+
+    @Override
+    public void onSaveError(ClientRuntimeError error) {
+        super.onSaveError(error);
+        if (isMigrating) {
+            isMigrating = false;
+            saveCallback.accept(false);
+        }
+    }
+
+    private BPMNProjectEditorMenuSessionItems getBPMNSessionItems() {
+        return (BPMNProjectEditorMenuSessionItems) getMenuSessionItems();
+    }
 }
