@@ -192,6 +192,9 @@ public class CaseManagementCanvasHandler<D extends Diagram, C extends WiresCanva
             if (applyProperties) {
                 applyElementTitle(caseManagementShape,
                                   candidate);
+
+                applyProperties(caseManagementShape,
+                                candidate);
             }
 
             caseManagementShape.getShapeView().refresh();
@@ -208,6 +211,15 @@ public class CaseManagementCanvasHandler<D extends Diagram, C extends WiresCanva
         ((CaseManagementShapeView) shape.getShapeView()).setLabel(name);
     }
 
+    @SuppressWarnings("unchecked")
+    private void applyProperties(final CaseManagementShape shape,
+                                 final Element candidate) {
+        shape.getShapeDef()
+                .viewHandler()
+                .accept(((Element<? extends View>) candidate).getContent().getDefinition(),
+                        shape.getShapeView());
+    }
+
     @Override
     public void applyElementMutation(final Element candidate,
                                      final boolean applyPosition,
