@@ -52,8 +52,19 @@ import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 @WithClassesToStub({BasicFileMenuBuilderImpl.class})
@@ -66,49 +77,33 @@ public class KieMultipleDocumentEditorTest
     @Test
     public void testSetupMenuBar() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         editor.setupMenuBar();
 
-        verify(fileMenuBuilder,
-               times(1)).addSave(any(MenuItem.class));
-        verify(fileMenuBuilder,
-               times(1)).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                 eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               times(1)).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                   eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               times(1)).addDelete(any(BasicFileMenuBuilder.PathProvider.class),
-                                   eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               times(1)).addValidate(any(Command.class));
-        verify(fileMenuBuilder,
-               times(2)).addNewTopLevelMenu(any(MenuItem.class));
+        verify(fileMenuBuilder).addSave(any(MenuItem.class));
+        verify(fileMenuBuilder).addCopy(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addRename(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addDelete(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addValidate(any(Command.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(downloadMenuItemButton);
+        verify(fileMenuBuilder, times(3)).addNewTopLevelMenu(any(MenuItem.class));
     }
 
     @Test
     public void testSetupMenuBarWithoutUpdateProjectPermission() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         editor.setupMenuBar();
 
-        verify(fileMenuBuilder,
-               never()).addSave(any(MenuItem.class));
-        verify(fileMenuBuilder,
-               never()).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               never()).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                  eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class),
-                                  eq(assetUpdateValidator));
-        verify(fileMenuBuilder,
-               times(1)).addValidate(any(Command.class));
-        verify(fileMenuBuilder,
-               times(2)).addNewTopLevelMenu(any(MenuItem.class));
+        verify(fileMenuBuilder, never()).addSave(any(MenuItem.class));
+        verify(fileMenuBuilder, never()).addCopy(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder, never()).addRename(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder, never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addValidate(any(Command.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(downloadMenuItemButton);
+        verify(fileMenuBuilder, times(3)).addNewTopLevelMenu(any(MenuItem.class));
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -594,19 +589,6 @@ public class KieMultipleDocumentEditorTest
                times(1)).getTitleWidget();
     }
 
-    @Test
-    public void testMayCloseChange() {
-        final TestDocument document = createTestDocument();
-
-        registerDocument(document);
-        activateDocument(document);
-
-        editor.mayClose(0,
-                        null);
-        verify(editorView,
-               times(1)).confirmClose();
-    }
-
     @Test
     public void testMayCloseNoChange() {
         final TestDocument document = createTestDocument();
@@ -664,13 +646,13 @@ public class KieMultipleDocumentEditorTest
         editor.getSaveMenuItem();
 
         verify(versionRecordManager,
-               times(1)).newSaveMenuItem(any(Command.class));
+               times(1)).newSaveMenuItem(any(ParameterizedCommand.class));
     }
 
     @Test
     public void testSave() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         final TestDocument document = createTestDocument();
         registerDocument(document);
@@ -678,13 +660,13 @@ public class KieMultipleDocumentEditorTest
 
         editor.getSaveMenuItem();
 
-        final ArgumentCaptor<Command> saveCommandCaptor = ArgumentCaptor.forClass(Command.class);
+        final ArgumentCaptor<ParameterizedCommand> saveCommandCaptor = ArgumentCaptor.forClass(ParameterizedCommand.class);
         verify(versionRecordManager,
                times(1)).newSaveMenuItem(saveCommandCaptor.capture());
 
-        final Command saveCommand = saveCommandCaptor.getValue();
+        final ParameterizedCommand<Boolean> saveCommand = saveCommandCaptor.getValue();
         assertNotNull(saveCommand);
-        saveCommand.execute();
+        saveCommand.execute(true);
 
         verify(editorView,
                times(1)).showSaving();
@@ -752,6 +734,7 @@ public class KieMultipleDocumentEditorTest
 
     @Test
     public void testOnRepositoryRemoved() {
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
         final Repository repository = mock(Repository.class);
         when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.of(new WorkspaceProject(mock(OrganizationalUnit.class),
                                                                                                        repository,
